; Boring Stuff DYCP part by gerliczer
; programmed during the 2019-12-21..2020-12-19 period
; final integration update on 2023-12-29..30
; created with Csabo's Plus4IDE 1.70 and
; Frank A. Kingswood's AS65 1.42
; tested in Gaia's YAPE and IstvanV's plus4emu
; thanks to all of you guys
; upload only to strictly CBM264 series related sites
; PAL&NTSC compatible program, 64kB memory required

; Big Mac music by Tony Kelly (C) 1985


PLAY_MUSIC				equ		1
LOGO_FADE_DELAY				equ		0	; fade delay in frames [0 turns off feature]


dycp_font_array				equ		$58	; 20 bytes $58..$6B
dycp_sine_array				equ		$88	; 20 bytes $88..$9B
dycp_char_array				equ		$B1	; 20 byets $B1..$C4
top_swing_index				equ		$D8	; upper logo swing position reference
bottom_swing_index			equ		$D9	; lower logo swing position reference
top_swing_flag				equ		$DA	; flag to main programme: drive upper logo swing
bottom_swing_flag			equ		$DB	; flag to main programme: drive lower logo swing
dycp_flag				equ		$DC	; flag to main programme: drive dycp
dycp_char_counter			equ		$DD	; counter for font width (2)
dycp_text_pos				equ		$DE	; pointer to the current scroll character
dycp_text_pos_high			equ		$DF
dycp_array_index			equ		$E0	; dycp processing index
dycp_font_read				equ		$E1	; dycp font read position
dycp_font_read_high			equ		$E2
dycp_font_read_2			equ		$E3	; dycp font read 2nd position
dycp_font_read_2_high			equ		$E4
logo_fade_index				equ		$E5
dycp_fade_index				equ		$E6
	if LOGO_FADE_DELAY
logo_fade_delay                         equ		$E7
dycp_fade_delay				equ		$E8
	endif


zp_1_bmm				equ		$D0
zp_2_bmm				equ		$D1


BACKGROUND				equ		$FF15

	org $1001-2
	dw  $1001
	
	dw nextln,2019	; second word is line number
	db $9E
	if start > 9999
	db "0"+start/10000
	endif
	db "0"+(start/1000)%10,"0"+(start/100)%10,"0"+(start/10)%10,"0"+start%10,0
nextln	db 0,0
	
start
	sei
	lda $FF80			; check ROM TV-system signature
	bmi pal_machine
	lda #226
	db $2c				; BIT jump
pal_machine
	lda #251
	sta wait_vblank_line
	jsr wait_vblank
	lda #$0B			; close screen
	sta $FF06
	lda #0
	sta $FF15			; set black backgroung and border
	sta $FF19
	sta top_swing_index		; initialize effect variables
	sta bottom_swing_index
	sta top_swing_flag
	sta bottom_swing_flag
	sta logo_fade_index
	sta dycp_fade_index
	sta dycp_array_index
	lda #2
	sta dycp_char_counter
	lda #lo(scroll_text)
	sta dycp_text_pos
	lda #hi(scroll_text)
	sta dycp_text_pos_high
	lda #$FF			; initialize music variables
	sta zp_1_bmm
	sta zp_2_bmm
	if LOGO_FADE_DELAY
	lda #2
	sta logo_fade_delay
	sta dycp_fade_delay
	endif
					; memory initialization
	ldx #$08			; Number of pages
	ldy #$08			; Hi byte of address ($0800)
	lda #$00			; Byte to fill
	jsr $C5A7
	ldx #$08			; Number of pages
	ldy #$28			; Hi byte of address ($2800)
	lda #$FF			; Byte to fill
	jsr $C5A7       		
	ldx #0				; init variable arrays
init_dycp_font_array
	txa
	sta dycp_font_array,x
	sta dycp_sine_array,x
	lda #$20
	sta dycp_char_array,x
	inx
	cpx #20
	bne init_dycp_font_array
	ldy #0
	ldx #-20
	sta $FF3F			; page ROM away
	ldx #4				; copy logos to screen
	jsr copy_logo_data_top
	ldx #4
	jsr copy_logo_data_bottom
	jsr wait_vblank
	lda #$1B			; open screen
	sta $FF06
	lda $FF07			; 38 column mode with 256 characters
	and #%11110111
	ora #%10000000
	sta $FF07
	lda $FF12			; chargen from RAM
	and #%11111011
	sta $FF12
	lda #$20			; select logo font
	sta $FF13
	lda #$08			; select default screen memory
	sta $FF14
	lda #66				; set first raster interrupt position
	sta $FF0B
	lda #2				; raster interrupt only
	sta $FF0A
	asl $FF09			; clear pending interrupt
	lda #lo(irq_1)			; set up interrupt vector
	sta $FFFE
	lda #hi(irq_1)
	sta $FFFF
	cli
fade_in_loop_1
	jsr top_fade_in
	jsr top_logo
	jsr bottom_fade_in
	jsr bottom_logo
	lda #logo_fade_length
	cmp logo_fade_index
	bne fade_in_loop_1
	lda #0
	sta dycp_flag
	lda #$20
	sta music_call_inst
fade_in_loop_2
	lda dycp_font_array+ 0
	ldy dycp_char_array+ 0
	ldx dycp_sine_array+ 0
	inc dycp_sine_array+ 0
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 1
	ldy dycp_char_array+ 1
	ldx dycp_sine_array+ 1
	inc dycp_sine_array+ 1
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 2
	ldy dycp_char_array+ 2
	ldx dycp_sine_array+ 2
	inc dycp_sine_array+ 2
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 3
	ldy dycp_char_array+ 3
	ldx dycp_sine_array+ 3
	inc dycp_sine_array+ 3
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 4
	ldy dycp_char_array+ 4
	ldx dycp_sine_array+ 4
	inc dycp_sine_array+ 4
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 5
	ldy dycp_char_array+ 5
	ldx dycp_sine_array+ 5
	inc dycp_sine_array+ 5
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 6
	ldy dycp_char_array+ 6
	ldx dycp_sine_array+ 6
	inc dycp_sine_array+ 6
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 7
	ldy dycp_char_array+ 7
	ldx dycp_sine_array+ 7
	inc dycp_sine_array+ 7
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 8
	ldy dycp_char_array+ 8
	ldx dycp_sine_array+ 8
	inc dycp_sine_array+ 8
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 9
	ldy dycp_char_array+ 9
	ldx dycp_sine_array+ 9
	inc dycp_sine_array+ 9
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+10
	ldy dycp_char_array+10
	ldx dycp_sine_array+10
	inc dycp_sine_array+10
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+11
	ldy dycp_char_array+11
	ldx dycp_sine_array+11
	inc dycp_sine_array+11
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+12
	ldy dycp_char_array+12
	ldx dycp_sine_array+12
	inc dycp_sine_array+12
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+13
	ldy dycp_char_array+13
	ldx dycp_sine_array+13
	inc dycp_sine_array+13
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+14
	ldy dycp_char_array+14
	ldx dycp_sine_array+14
	inc dycp_sine_array+14
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+15
	ldy dycp_char_array+15
	ldx dycp_sine_array+15
	inc dycp_sine_array+15
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+16
	ldy dycp_char_array+16
	ldx dycp_sine_array+16
	inc dycp_sine_array+16
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+17
	ldy dycp_char_array+17
	ldx dycp_sine_array+17
	inc dycp_sine_array+17
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+18
	ldy dycp_char_array+18
	ldx dycp_sine_array+18
	inc dycp_sine_array+18
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+19
	ldy dycp_char_array+19
	ldx dycp_sine_array+19
	inc dycp_sine_array+19
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_in
	jsr mid_dycp
	jsr bottom_logo
	lda #dycp_fade_length
	cmp dycp_fade_index
	beq to_main_loop
	jmp fade_in_loop_2
to_main_loop
	jmp main_loop

exit_part
	sei
	jsr wait_vblank
	jsr wait_line
	jsr wait_vblank
;	sta $FF3E
;	jmp $FFF6
	lda #0
	sta $FF0A
	sta $FF15
	sta $FF19
	asl $FF09
	lda $FF06
	and #$EF
	sta $FF06
	lda #1
	jmp $FF40

wait_line
	lda $FF1D
	cmp $FF1D
	beq *-3
	rts

	align 256			; FREE $1269-$12FF

top_logo
	lda top_swing_flag
	beq top_logo_exit
	ldx top_swing_index
	ldy logo_copy_pos,x
	inx
	stx top_swing_index
	lda logo_scroll_pos,x
	sta top_scroll_pos
	tya
	cmp logo_copy_pos,x
	beq no_top_logo_copy
	lda logo_copy_pos,x
	tax
	jsr copy_logo_data_top
no_top_logo_copy
	dec top_swing_flag
top_logo_exit
	rts

dycp_update
	sty dycp_char_index		; store next scroll text character index
	asl a				; turn next character to word table index
	tay
	lda fill_call_table,y		; get specific fill routine address low byte
	sta fill_call			; store to subroutine call address
	iny
	lda fill_call_table,y		; get specific fill routine address high byte
	sta fill_call_high		; store to subroutine call address
dycp_char_index				equ		*+1
	ldy #0
	lda dycp_font_low,y		; set up copy source pointers
	sta dycp_font_read
	ora #$10
	sta dycp_font_read_2
	lda dycp_font_high,y
	sta dycp_font_read_high
	sta dycp_font_read_2_high
	lda dycp_sine_table,x		; get sine phase
	tax
fill_call				equ		*+1
fill_call_high				equ		*+2
	jsr $FFFF			; call specific copy routine
	rts

mid_dycp
	lda dycp_flag
	beq mid_dycp_exit
;	dec $FF19
	lda dycp_scroll_pos
	sec
	sbc #3
	sta dycp_scroll_pos
	bpl no_dycp_copy
	and #7
	sta dycp_scroll_pos
	jsr copy_dycp_data
	dec dycp_char_counter
	bne no_dycp_new_char
	jsr copy_dycp_arrays
	jsr new_dycp_char
no_dycp_new_char
no_dycp_copy
;	inc $FF19
	dec dycp_flag
mid_dycp_exit
	rts

new_dycp_char
;	dec $FF19
	lda #lo(scroll_text_end)	; check scroll text end
	cmp dycp_text_pos
	bne no_text_end
	lda #hi(scroll_text_end)
	cmp dycp_text_pos_high
	bne no_text_end
	lda #lo(scroll_text)		; restart if ended
	sta dycp_text_pos
	lda #hi(scroll_text)
	sta dycp_text_pos_high
no_text_end
	ldy #0
	lda (dycp_text_pos),y
	sta dycp_char_array+19
	lda #2
	sta dycp_char_counter
	inc dycp_text_pos		; move to next scroll text character
	bne end_new_dycp_char
	inc dycp_text_pos_high
end_new_dycp_char
;	inc $FF19
	rts

bottom_logo
	lda bottom_swing_flag
	beq bottom_logo_exit
	ldx bottom_swing_index
	ldy logo_copy_pos,x
	dex
	stx bottom_swing_index
	lda logo_scroll_pos,x
	sta bottom_scroll_pos
	tya
	cmp logo_copy_pos,x
	beq no_bottom_logo_copy
	lda logo_copy_pos,x
	tax
	jsr copy_logo_data_bottom
no_bottom_logo_copy
	dec bottom_swing_flag
bottom_logo_exit
	rts

wait_vblank
wait_vblank_line			equ		*+1
	lda #$CC
	cmp $FF1D
	bne *-3
	rts

copy_logo_data_top
;	dec $FF19
	ldy #0
copy_top_loop
	lda logo_screen_data+0*40+ 0,x
	sta $C00+ 0,y
	lda logo_screen_data+0*40+10,x
	sta $C00+10,y
	lda logo_screen_data+0*40+20,x
	sta $C00+20,y
	lda logo_screen_data+0*40+30,x
	sta $C00+30,y
	lda logo_screen_data+1*40+ 0,x
	sta $C28+ 0,y
	lda logo_screen_data+1*40+10,x
	sta $C28+10,y
	lda logo_screen_data+1*40+20,x
	sta $C28+20,y
	lda logo_screen_data+1*40+30,x
	sta $C28+30,y
	lda logo_screen_data+2*40+ 0,x
	sta $C50+ 0,y
	lda logo_screen_data+2*40+10,x
	sta $C50+10,y
	lda logo_screen_data+2*40+20,x
	sta $C50+20,y
	lda logo_screen_data+2*40+30,x
	sta $C50+30,y
	lda logo_screen_data+3*40+ 0,x
	sta $C78+ 0,y
	lda logo_screen_data+3*40+10,x
	sta $C78+10,y
	lda logo_screen_data+3*40+20,x
	sta $C78+20,y
	lda logo_screen_data+3*40+30,x
	sta $C78+30,y
	lda logo_screen_data+4*40+ 0,x
	sta $CA0+ 0,y
	lda logo_screen_data+4*40+10,x
	sta $CA0+10,y
	lda logo_screen_data+4*40+20,x
	sta $CA0+20,y
	lda logo_screen_data+4*40+30,x
	sta $CA0+30,y
	lda logo_screen_data+5*40+ 0,x
	sta $CC8+ 0,y
	lda logo_screen_data+5*40+10,x
	sta $CC8+10,y
	lda logo_screen_data+5*40+20,x
	sta $CC8+20,y
	lda logo_screen_data+5*40+30,x
	sta $CC8+30,y
	lda logo_screen_data+6*40+ 0,x
	sta $CF0+ 0,y
	lda logo_screen_data+6*40+10,x
	sta $CF0+10,y
	lda logo_screen_data+6*40+20,x
	sta $CF0+20,y
	lda logo_screen_data+6*40+30,x
	sta $CF0+30,y
	lda logo_screen_data+7*40+ 0,x
	sta $D18+ 0,y
	lda logo_screen_data+7*40+10,x
	sta $D18+10,y
	lda logo_screen_data+7*40+20,x
	sta $D18+20,y
	lda logo_screen_data+7*40+30,x
	sta $D18+30,y
	inx
	iny
	cpy #10
	beq *+5
	jmp copy_top_loop
;	inc $FF19
	rts

copy_logo_data_bottom
;	dec $FF19
	ldy #0
copy_bottom_loop
	lda logo_screen_data+0*40+ 0,x
	sta $EA8+ 0,y
	lda logo_screen_data+0*40+10,x
	sta $EA8+10,y
	lda logo_screen_data+0*40+20,x
	sta $EA8+20,y
	lda logo_screen_data+0*40+30,x
	sta $EA8+30,y
	lda logo_screen_data+1*40+ 0,x
	sta $ED0+ 0,y
	lda logo_screen_data+1*40+10,x
	sta $ED0+10,y
	lda logo_screen_data+1*40+20,x
	sta $ED0+20,y
	lda logo_screen_data+1*40+30,x
	sta $ED0+30,y
	lda logo_screen_data+2*40+ 0,x
	sta $EF8+ 0,y
	lda logo_screen_data+2*40+10,x
	sta $EF8+10,y
	lda logo_screen_data+2*40+20,x
	sta $EF8+20,y
	lda logo_screen_data+2*40+30,x
	sta $EF8+30,y
	lda logo_screen_data+3*40+ 0,x
	sta $F20+ 0,y
	lda logo_screen_data+3*40+10,x
	sta $F20+10,y
	lda logo_screen_data+3*40+20,x
	sta $F20+20,y
	lda logo_screen_data+3*40+30,x
	sta $F20+30,y
	lda logo_screen_data+4*40+ 0,x
	sta $F48+ 0,y
	lda logo_screen_data+4*40+10,x
	sta $F48+10,y
	lda logo_screen_data+4*40+20,x
	sta $F48+20,y
	lda logo_screen_data+4*40+30,x
	sta $F48+30,y
	lda logo_screen_data+5*40+ 0,x
	sta $F70+ 0,y
	lda logo_screen_data+5*40+10,x
	sta $F70+10,y
	lda logo_screen_data+5*40+20,x
	sta $F70+20,y
	lda logo_screen_data+5*40+30,x
	sta $F70+30,y
	lda logo_screen_data+6*40+ 0,x
	sta $F98+ 0,y
	lda logo_screen_data+6*40+10,x
	sta $F98+10,y
	lda logo_screen_data+6*40+20,x
	sta $F98+20,y
	lda logo_screen_data+6*40+30,x
	sta $F98+30,y
	lda logo_screen_data+7*40+ 0,x
	sta $FC0+ 0,y
	lda logo_screen_data+7*40+10,x
	sta $FC0+10,y
	lda logo_screen_data+7*40+20,x
	sta $FC0+20,y
	lda logo_screen_data+7*40+30,x
	sta $FC0+30,y
	inx
	iny
	cpy #10
	beq *+5
	jmp copy_bottom_loop
;	inc $FF19
	rts

	align 256			; FREE $1559-$15FF

irq_1
	pha
	lda $FF1E			; stabilize raster position
	lsr a
	lsr a
	sta *+4
	bpl *
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C5
	nop
	asl $FF09
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	lda $FF07
	ora #$10
	sta $FF07
	lda #$57
	sta $FF06
	lda #$05
	sta $FF1F
	lda #lo(irq_2)
	sta $FFFE
	lda #hi(irq_2)
	sta $FFFF
	lda $00
	lda #$28
	sta $FF13
	lda #$18
	sta $FF14
	lda #129;4
	sta $FF0B
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
dycp_colour_0				equ		*+1
	lda #$0
	sta BACKGROUND
	lda $FF07
	and #$E8
dycp_scroll_pos				equ		*+1
	ora #0
	sta $FF07
	lda #$17
	sta $FF06
	lda #$00
	sta $FF1F
	nop
	nop
	nop
	nop
	nop
	nop
	nop
dycp_colour_1				equ		*+1
	lda #$0
	sta BACKGROUND
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop	
dycp_colour_2				equ		*+1
	lda #$0
	sta BACKGROUND
	inc top_swing_flag
	pla
	rti

irq_2
	pha
	lda $FF1E			; stabilize raster position
	lsr a
	lsr a
	sta *+4
	bpl *
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C5
	nop
	asl $FF09
	lda #138
	sta $FF0B
	nop
	nop
	nop
	nop
	nop
	nop
dycp_colour_3				equ		*+1
	lda #$0
	sta BACKGROUND
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
dycp_colour_4				equ		*+1
	lda #$0
	sta BACKGROUND
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	lda $FF07
	and #$F8
	ora #$10
bottom_scroll_pos			equ		*+1
	ora #0
	sta $FF07
	lda #$57
	sta $FF06
bottom_colour				equ		*+1
	lda #$0
	sta BACKGROUND			; raster line preceeding bottom logo
	lda #lo(irq_3)
	sta $FFFE
	lda #hi(irq_3)
	sta $FFFF
	inc dycp_flag
	pla
	rti

irq_3
	pha
	lda $FF1E			; stabilize raster position
	lsr a
	lsr a
	sta *+4
	bpl *
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C9
	cmp #$C5
	nop
	asl $FF09
	lda #$08
	sta $FF14
	lda #204
	sta $FF0B
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	lda #$20
	sta $FF13
	lda $FF07
	and #$EF
	sta $FF07
	lda #$1B
	sta $FF06
	lda #$07
	sta $FF1F
	lda #lo(irq_4)
	sta $FFFE
	lda #hi(irq_4)
	sta $FFFF
	pla
	rti

irq_4
	pha
	asl $FF09
	lda #66
	sta $FF0B
	lda $FF07
	and #$F8
top_scroll_pos				equ		*+1
	ora #0
	sta $FF07
top_colour				equ		*+1
	lda #$0
	sta BACKGROUND			; after bottom logo
	lda #lo(irq_1)
	sta $FFFE
	lda #hi(irq_1)
	sta $FFFF
	if PLAY_MUSIC
music_call_inst
	db $2C, lo(music_bmm), hi(music_bmm)
	endif
	inc bottom_swing_flag
	pla
	rti

					; FREE $17FB-$17FF

	org $1800

fill_call_table
	dw fill_dycp_chars_00_03,fill_dycp_chars_04_07,fill_dycp_chars_08_0B,fill_dycp_chars_0C_0F,fill_dycp_chars_10_13,fill_dycp_chars_14_17,fill_dycp_chars_18_1B
	dw fill_dycp_chars_1C_1F,fill_dycp_chars_20_23,fill_dycp_chars_24_27,fill_dycp_chars_28_2B,fill_dycp_chars_2C_2F,fill_dycp_chars_30_33,fill_dycp_chars_34_37
	dw fill_dycp_chars_38_3B,fill_dycp_chars_3C_3F,fill_dycp_chars_40_43,fill_dycp_chars_44_47,fill_dycp_chars_48_4B,fill_dycp_chars_4C_4F,fill_dycp_chars_50_53
	dw fill_dycp_chars_54_57,fill_dycp_chars_58_5B,fill_dycp_chars_5C_5F,fill_dycp_chars_60_63,fill_dycp_chars_64_67,fill_dycp_chars_68_6B,fill_dycp_chars_6C_6F
	dw fill_dycp_chars_70_73,fill_dycp_chars_74_77,fill_dycp_chars_78_7B,fill_dycp_chars_7C_7F,fill_dycp_chars_80_83,fill_dycp_chars_84_87,fill_dycp_chars_88_8B
	dw fill_dycp_chars_8C_8F,fill_dycp_chars_90_93,fill_dycp_chars_94_97,fill_dycp_chars_98_9B,fill_dycp_chars_9C_9F,fill_dycp_chars_A0_A3,fill_dycp_chars_A4_A7
	dw fill_dycp_chars_A8_AB,fill_dycp_chars_AC_AF,fill_dycp_chars_B0_B3,fill_dycp_chars_B4_B7,fill_dycp_chars_B8_BB,fill_dycp_chars_BC_BF,fill_dycp_chars_C0_C3
	dw fill_dycp_chars_C4_C7,fill_dycp_chars_C8_CB,fill_dycp_chars_CC_CF,fill_dycp_chars_D0_D3,fill_dycp_chars_D4_D7,fill_dycp_chars_D8_DB,fill_dycp_chars_DC_DF
	dw fill_dycp_chars_E0_E3,fill_dycp_chars_E4_E7,fill_dycp_chars_E8_EB,fill_dycp_chars_EC_EF,fill_dycp_chars_F0_F3,fill_dycp_chars_F4_F7,fill_dycp_chars_F8_FB
	dw fill_dycp_chars_FC_FF

low_nibbles
	db $00,$01,$02,$03,$04,$05,$06,$07,$08,$09,$0A,$0B,$0C,$0D,$0E,$0F,$00,$01,$02,$03,$04,$05,$06,$07,$08,$09,$0A,$0B,$0C,$0D,$0E,$0F
	db $00,$01,$02,$03,$04,$05,$06,$07,$08,$09,$0A,$0B,$0C,$0D,$0E,$0F,$00,$01,$02,$03,$04,$05,$06,$07,$08,$09,$0A,$0B,$0C,$0D,$0E,$0F

dycp_font_low
	db $00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0
	db $00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0,$00,$20,$40,$60,$80,$A0,$C0,$E0

dycp_font_high
	db $30,$30,$30,$30,$30,$30,$30,$30,$31,$31,$31,$31,$31,$31,$31,$31,$32,$32,$32,$32,$32,$32,$32,$32,$33,$33,$33,$33,$33,$33,$33,$33
	db $34,$34,$34,$34,$34,$34,$34,$34,$35,$35,$35,$35,$35,$35,$35,$35,$36,$36,$36,$36,$36,$36,$36,$36,$37,$37,$37,$37,$37,$37,$37,$37

					; FREE $1940-$1967

	org $1968

	ds 360

					; FREE $1AD0-$1AFF

	org $1B00

mdata_1_bmm		; channel 1
	db $0E, $0C, $0A, $0E, $0C, $0A, $0F, $0C
	db $0A, $0F, $0C, $0A, $0E, $0C, $0A, $0E
	db $0C, $0A, $11, $10, $0E, $0D, $0C, $0B
	db $0B, $0E, $0C, $0C, $0C, $0C, $0F, $0C
	db $0A, $0F, $0C, $0A, $0A, $0E, $0C, $0C
	db $0C, $0C, $11, $0E, $0B, $0E, $11, $13
	db $12, $10, $0D, $12, $10, $0D, $11, $0E
	db $0B, $0E, $11, $0E, $12, $10, $0D, $12
	db $10, $0D, $0D, $0E, $0C, $0B, $0B, $0B
	db $12, $10, $0D, $12, $10, $0D, $11, $0E
	db $11, $13, $12, $11, $12, $10, $0D, $12
	db $10, $0D, $11, $10, $0E, $0D, $0C, $0B
mdata_2_bmm		; channel 2
	db $06, $06, $02, $06, $04, $02, $07, $07
	db $02, $07, $04, $02, $06, $06, $02, $06
	db $04, $02, $09, $09, $09, $06, $06, $06
	db $02, $02, $02, $06, $04, $02, $07, $07
	db $07, $07, $07, $07, $02, $02, $02, $06
	db $04, $02, $03, $03, $03, $09, $09, $09
	db $05, $05, $0A, $05, $05, $0A, $03, $03
	db $03, $09, $09, $09, $05, $05, $0A, $05
	db $05, $0A, $03, $03, $03, $06, $05, $04
	db $05, $05, $0A, $05, $05, $0A, $0D, $0D
	db $0D, $0B, $0B, $0B, $05, $05, $0A, $05
	db $05, $0A, $03, $03, $09, $08, $08, $06
mdata_3_bmm		; note low
	db $00, $00, $58, $87, $B0, $C3, $E5, $F5
	db $04, $20, $2C, $43, $58, $61, $73, $7B
	db $82, $90, $96, $A2, $00, $00, $00, $00
mdata_4_bmm		; note high
	db $00, $00, $02, $02, $02, $02, $02, $02
	db $03, $03, $03, $03, $03, $03, $03, $03
	db $03, $03, $03, $03, $00, $00, $00, $00

					; FREE $1BF0-$1D67

	org $1D68

	db  0, 2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78
	db  1, 3, 5, 7, 9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79
	db  0, 2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78
	db  1, 3, 5, 7, 9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79
	db  0, 2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78
	db  1, 3, 5, 7, 9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79
	db  0, 2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78
	db  1, 3, 5, 7, 9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79


					; FREE $1EA8-$1EFF

	org $1F00

music_bmm
	stx saved_x_bmm
	sty saved_y_bmm
	inc zp_1_bmm
	lda zp_1_bmm
	cmp #7
	bne exit_bmm
	lda #0
	sta zp_1_bmm
vol_bmm					equ		*+1
	lda #$38
	sta $FF11
	inc zp_2_bmm
	lda zp_2_bmm
	cmp #$60
	bne skip_rs_bmm
	lda #0
	sta zp_2_bmm
skip_rs_bmm
	ldx zp_2_bmm
	ldy mdata_1_bmm,x
	lda mdata_3_bmm,y
	sta $FF0E
	lda $FF12
	and #$FC
	ora mdata_4_bmm,y
	sta $FF12
	ldy mdata_2_bmm,x
	lda mdata_3_bmm,y
	sta $FF0F
	lda $FF10
	and #$FC
	ora mdata_4_bmm,y
	sta $FF10
exit_bmm
saved_y_bmm				equ		*+1
	ldy #0
saved_x_bmm				equ		*+1
	ldx #0
	rts

					; FREE $1F53-$1FFF

	org $2000	; logo font + logo screen data

	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF ; $00,$00,$00,$00,$00,$00,$00,$00	; $00 
	db $FF,$FF,$FF,$FF,$FE,$FE,$C0,$C0 ; $00,$00,$00,$00,$01,$01,$3F,$3F	; $01
	db $80,$80,$80,$80,$81,$81,$83,$83 ; $7F,$7F,$7F,$7F,$7E,$7E,$7C,$7C	; $02
	db $83,$83,$83,$83,$83,$83,$82,$82 ; $7C,$7C,$7C,$7C,$7C,$7C,$7D,$7D	; $03
	db $82,$82,$83,$83,$03,$03,$03,$03 ; $7D,$7D,$7C,$7C,$FC,$FC,$FC,$FC	; $04
	db $07,$07,$07,$07,$07,$07,$07,$07 ; $F8,$F8,$F8,$F8,$F8,$F8,$F8,$F8	; $05
	db $07,$07,$07,$07,$04,$04,$04,$04 ; $F8,$F8,$F8,$F8,$FB,$FB,$FB,$FB	; $06
	db $FC,$FC,$FE,$FE,$FF,$FF,$FF,$FF ; $03,$03,$01,$01,$00,$00,$00,$00	; $07
	db $FF,$FF,$E0,$E0,$00,$00,$00,$00 ; $00,$00,$1F,$1F,$FF,$FF,$FF,$FF	; $08
	db $0F,$0F,$FF,$FF,$FF,$FF,$FF,$FF ; $F0,$F0,$00,$00,$00,$00,$00,$00	; $09
	db $FC,$FC,$F8,$F8,$00,$00,$00,$00 ; $03,$03,$07,$07,$FF,$FF,$FF,$FF	; $0A
	db $07,$07,$FF,$FF,$FF,$FF,$FF,$FF ; $F8,$F8,$00,$00,$00,$00,$00,$00	; $0B
	db $FF,$FF,$FF,$FF,$0C,$0C,$00,$00 ; $00,$00,$00,$00,$F3,$F3,$FF,$FF	; $0C
	db $00,$00,$00,$00,$FF,$FF,$FF,$FF ; $FF,$FF,$FF,$FF,$00,$00,$00,$00	; $0D
	db $FF,$FF,$0F,$0F,$03,$03,$01,$01 ; $00,$00,$F0,$F0,$FC,$FC,$FE,$FE	; $0E
	db $C1,$C1,$C1,$C1,$C1,$C1,$83,$83 ; $3E,$3E,$3E,$3E,$3E,$3E,$7C,$7C	; $0F
	db $0F,$0F,$1F,$1F,$1F,$1F,$03,$03 ; $F0,$F0,$E0,$E0,$E0,$E0,$FC,$FC	; $10
	db $81,$81,$C0,$C0,$E0,$E0,$F0,$F0 ; $7E,$7E,$3F,$3F,$1F,$1F,$0F,$0F	; $11
	db $F0,$F0,$E0,$E0,$E0,$E0,$C0,$C0 ; $0F,$0F,$1F,$1F,$1F,$1F,$3F,$3F	; $12
	db $81,$81,$01,$01,$03,$03,$0F,$0F ; $7E,$7E,$FE,$FE,$FC,$FC,$F0,$F0	; $13
	db $3F,$3F,$FF,$FF,$FF,$FF,$FF,$FF ; $C0,$C0,$00,$00,$00,$00,$00,$00	; $14
	db $FF,$FF,$FF,$FF,$FE,$FE,$FC,$FC ; $00,$00,$00,$00,$01,$01,$03,$03	; $15
	db $FC,$FC,$F8,$F8,$70,$70,$70,$70 ; $03,$03,$07,$07,$8F,$8F,$8F,$8F	; $16
	db $41,$41,$41,$41,$C1,$C1,$C1,$C1 ; $BE,$BE,$BE,$BE,$3E,$3E,$3E,$3E	; $17
	db $C1,$C1,$C0,$C0,$F0,$F0,$FF,$FF ; $3E,$3E,$3F,$3F,$0F,$0F,$00,$00	; $18
	db $E0,$E0,$00,$00,$00,$00,$08,$08 ; $1F,$1F,$FF,$FF,$FF,$FF,$F7,$F7	; $19
	db $1F,$1F,$3F,$3F,$3F,$3F,$FF,$FF ; $E0,$E0,$C0,$C0,$C0,$C0,$00,$00	; $1A
	db $FF,$FF,$FC,$FC,$FC,$FC,$F0,$F0 ; $00,$00,$03,$03,$03,$03,$0F,$0F	; $1B
	db $E0,$E0,$00,$00,$0F,$0F,$FF,$FF ; $1F,$1F,$FF,$FF,$F0,$F0,$00,$00	; $1C
	db $7F,$7F,$3F,$3F,$1F,$1F,$03,$03 ; $80,$80,$C0,$C0,$E0,$E0,$FC,$FC	; $1D
	db $00,$00,$00,$00,$0F,$0F,$0F,$0F ; $FF,$FF,$FF,$FF,$F0,$F0,$F0,$F0	; $1E
	db $0F,$0F,$1F,$1F,$1F,$1F,$3F,$3F ; $F0,$F0,$E0,$E0,$E0,$E0,$C0,$C0	; $1F
	db $7F,$7F,$FF,$FF,$FF,$FF,$FF,$FF ; $80,$80,$00,$00,$00,$00,$00,$00	; $20
	db $FF,$FF,$F8,$F8,$F0,$F0,$F0,$F0 ; $00,$00,$07,$07,$0F,$0F,$0F,$0F	; $21
	db $00,$00,$00,$00,$F0,$F0,$F1,$F1 ; $FF,$FF,$FF,$FF,$0F,$0F,$0E,$0E	; $22
	db $F0,$F0,$F0,$F0,$C0,$C0,$C0,$C0 ; $0F,$0F,$0F,$0F,$3F,$3F,$3F,$3F	; $23
	db $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0 ; $3F,$3F,$3F,$3F,$3F,$3F,$3F,$3F	; $24
	db $F1,$F1,$FF,$FF,$FF,$FF,$FF,$FF ; $0E,$0E,$00,$00,$00,$00,$00,$00	; $25
	db $FF,$FF,$FF,$FF,$FC,$FC,$F0,$F0 ; $00,$00,$00,$00,$03,$03,$0F,$0F	; $26
	db $E0,$E0,$C3,$C3,$07,$07,$0F,$0F ; $1F,$1F,$3C,$3C,$F8,$F8,$F0,$F0	; $27
	db $0F,$0F,$1F,$1F,$1F,$1F,$3F,$3F ; $F0,$F0,$E0,$E0,$E0,$E0,$C0,$C0	; $28
	db $3F,$3F,$FF,$FF,$FF,$FF,$FF,$FF ; $C0,$C0,$00,$00,$00,$00,$00,$00 	; $29
	db $FF,$FF,$FF,$FF,$03,$03,$03,$03 ; $00,$00,$00,$00,$FC,$FC,$FC,$FC	; $2A
	db $3F,$3F,$FF,$FF,$FF,$FF,$FF,$FF ; $C0,$C0,$00,$00,$00,$00,$00,$00	; $2B
	db $E0,$E0,$C0,$C0,$C0,$C0,$C1,$C1 ; $1F,$1F,$3F,$3F,$3F,$3F,$3E,$3E	; $2C
	db $FF,$FF,$FF,$FF,$8F,$8F,$0F,$0F ; $00,$00,$00,$00,$70,$70,$F0,$F0	; $2D
	db $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F ; $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0	; $2E
	db $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F ; $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0	; $2F
	db $0F,$0F,$02,$02,$80,$80,$80,$80 ; $F0,$F0,$FD,$FD,$7F,$7F,$7F,$7F	; $30
	db $C0,$C0,$FF,$FF,$FF,$FF,$FF,$FF ; $3F,$3F,$00,$00,$00,$00,$00,$00	; $31
	db $FF,$FF,$FF,$FF,$FF,$FF,$FE,$FE ; $00,$00,$00,$00,$00,$00,$01,$01	; $32
	db $FC,$FC,$F8,$F8,$F0,$F0,$C0,$C0 ; $03,$03,$07,$07,$0F,$0F,$3F,$3F	; $33
	db $81,$81,$03,$03,$07,$07,$3F,$3F ; $7E,$7E,$FC,$FC,$F8,$F8,$C0,$C0	; $34
	db $7F,$7F,$FF,$FF,$FF,$FF,$FF,$FF ; $80,$80,$00,$00,$00,$00,$00,$00	; $35
	db $FF,$FF,$E3,$E3,$E3,$E3,$C3,$C3 ; $00,$00,$1C,$1C,$1C,$1C,$3C,$3C	; $36
	db $C3,$C3,$C3,$C3,$07,$07,$04,$04 ; $3C,$3C,$3C,$3C,$F8,$F8,$FB,$FB	; $37
	db $00,$00,$00,$00,$00,$00,$00,$00 ; $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF	; $38
	db $03,$03,$C7,$C7,$FF,$FF,$FF,$FF ; $FC,$FC,$38,$38,$00,$00,$00,$00	; $39
	db $FF,$FF,$FF,$FF,$E0,$E0,$C0,$C0 ; $00,$00,$00,$00,$1F,$1F,$3F,$3F	; $3A
	db $80,$80,$00,$00,$0E,$0E,$1E,$1E ; $7F,$7F,$FF,$FF,$F1,$F1,$E1,$E1	; $3B
	db $3E,$3E,$7E,$7E,$7E,$7E,$FF,$FF ; $C1,$C1,$81,$81,$81,$81,$00,$00	; $3C
	db $FF,$FF,$FF,$FF,$7F,$7F,$3F,$3F ; $00,$00,$00,$00,$80,$80,$C0,$C0	; $3D
	db $3F,$3F,$0F,$0F,$0F,$0F,$0F,$0F ; $C0,$C0,$F0,$F0,$F0,$F0,$F0,$F0	; $3E
	db $0F,$0F,$0F,$0F,$0F,$0F,$06,$06 ; $F0,$F0,$F0,$F0,$F0,$F0,$F9,$F9	; $3F
	db $00,$00,$00,$00,$80,$80,$FF,$FF ; $FF,$FF,$FF,$FF,$7F,$7F,$00,$00	; $40
	db $FF,$FF,$FC,$FC,$F8,$F8,$F8,$F8 ; $00,$00,$03,$03,$07,$07,$07,$07	; $41
	db $F0,$F0,$C0,$C0,$00,$00,$00,$00 ; $0F,$0F,$3F,$3F,$FF,$FF,$FF,$FF	; $42
	db $00,$00,$30,$30,$F0,$F0,$FF,$FF ; $FF,$FF,$CF,$CF,$0F,$0F,$00,$00	; $43
	db $FF,$FF,$FF,$FF,$FF,$FF,$CF,$CF ; $00,$00,$00,$00,$00,$00,$30,$30	; $44
	db $C3,$C3,$E0,$E0,$F0,$F0,$FC,$FC ; $3C,$3C,$1F,$1F,$0F,$0F,$03,$03	; $45
	db $FF,$FF,$FF,$FF,$FF,$FF,$FC,$FC ; $00,$00,$00,$00,$00,$00,$03,$03	; $46
	db $E0,$E0,$C1,$C1,$83,$83,$0F,$0F ; $1F,$1F,$3E,$3E,$7C,$7C,$F0,$F0	; $47
	db $0F,$0F,$1F,$1F,$3F,$3F,$3F,$3F ; $F0,$F0,$E0,$E0,$C0,$C0,$C0,$C0	; $48
	db $7E,$7E,$7C,$7C,$70,$70,$40,$40 ; $81,$81,$83,$83,$8F,$8F,$BF,$BF	; $49
	db $01,$01,$0F,$0F,$3F,$3F,$FE,$FE ; $FE,$FE,$F0,$F0,$C0,$C0,$01,$01	; $4A
	db $FE,$FE,$FE,$FE,$FE,$FE,$FE,$FE ; $01,$01,$01,$01,$01,$01,$01,$01	; $4B
	db $FC,$FC,$70,$70,$00,$00,$01,$01 ; $03,$03,$8F,$8F,$FF,$FF,$FE,$FE	; $4C
	db $FF,$FF,$FF,$FF,$FF,$FF,$07,$07 ; $00,$00,$00,$00,$00,$00,$F8,$F8	; $4D
	db $07,$07,$03,$03,$07,$07,$07,$07 ; $F8,$F8,$FC,$FC,$F8,$F8,$F8,$F8	; $4E
	db $07,$07,$07,$07,$07,$07,$07,$07 ; $F8,$F8,$F8,$F8,$F8,$F8,$F8,$F8	; $4F
	db $07,$07,$07,$07,$07,$07,$07,$07 ; $F8,$F8,$F8,$F8,$F8,$F8,$F8,$F8	; $50
	db $07,$07,$0F,$0F,$0F,$0F,$0F,$0F ; $F8,$F8,$F0,$F0,$F0,$F0,$F0,$F0	; $51
	db $0F,$0F,$0F,$0F,$3F,$3F,$3F,$3F ; $F0,$F0,$F0,$F0,$C0,$C0,$C0,$C0	; $52
	db $3F,$3F,$7F,$7F,$FF,$FF,$FF,$FF ; $C0,$C0,$80,$80,$00,$00,$00,$00	; $53
	db $FF,$FF,$FF,$FF,$FE,$FE,$FE,$FE ; $00,$00,$00,$00,$01,$01,$01,$01	; $54
	db $FE,$FE,$FE,$FE,$FE,$FE,$FF,$FF ; $01,$01,$01,$01,$01,$01,$00,$00	; $55
	db $FF,$FF,$FF,$FF,$FC,$FC,$FC,$FC ; $00,$00,$00,$00,$03,$03,$03,$03	; $56
	db $FC,$FC,$FE,$FE,$FF,$FF,$FF,$FF ; $03,$03,$01,$01,$00,$00,$00,$00	; $57
	db $FF,$FF,$FF,$FF,$F8,$F8,$C0,$C0 ; $00,$00,$00,$00,$07,$07,$3F,$3F	; $58
	db $00,$00,$03,$03,$07,$07,$0F,$0F ; $FF,$FF,$FC,$FC,$F8,$F8,$F0,$F0	; $59
	db $0F,$0F,$0F,$0F,$07,$07,$01,$01 ; $F0,$F0,$F0,$F0,$F8,$F8,$FE,$FE	; $5A
	db $80,$80,$F0,$F0,$FC,$FC,$FF,$FF ; $7F,$7F,$0F,$0F,$03,$03,$00,$00	; $5B
	db $FF,$FF,$FF,$FF,$3E,$3E,$00,$00 ; $00,$00,$00,$00,$C1,$C1,$FF,$FF	; $5C
	db $00,$00,$00,$00,$FF,$FF,$FF,$FF ; $FF,$FF,$FF,$FF,$00,$00,$00,$00	; $5D
	db $FF,$FF,$00,$00,$00,$00,$00,$00 ; $00,$00,$FF,$FF,$FF,$FF,$FF,$FF	; $5E
	db $3F,$3F,$FF,$FF,$FF,$FF,$FF,$FF ; $C0,$C0,$00,$00,$00,$00,$00,$00	; $5F
	db $1F,$1F,$03,$03,$00,$00,$C0,$C0 ; $E0,$E0,$FC,$FC,$FF,$FF,$3F,$3F	; $60
	db $F8,$F8,$FC,$FC,$FF,$FF,$FC,$FC ; $07,$07,$03,$03,$00,$00,$03,$03	; $61
	db $F8,$F8,$E0,$E0,$00,$00,$03,$03 ; $07,$07,$1F,$1F,$FF,$FF,$FC,$FC	; $62
	db $0F,$0F,$FF,$FF,$FF,$FF,$FF,$FF ; $F0,$F0,$00,$00,$00,$00,$00,$00	; $63
	db $FF,$FF,$3F,$3F,$0F,$0F,$03,$03 ; $00,$00,$C0,$C0,$F0,$F0,$FC,$FC	; $64
	db $03,$03,$83,$83,$8F,$8F,$FF,$FF ; $FC,$FC,$7C,$7C,$70,$70,$00,$00	; $65
	db $F0,$F0,$F0,$F0,$7F,$7F,$1F,$1F ; $0F,$0F,$0F,$0F,$80,$80,$E0,$E0	; $66
	db $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F ; $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0	; $67
	db $1F,$1F,$3F,$3F,$7F,$7F,$FF,$FF ; $E0,$E0,$C0,$C0,$80,$80,$00,$00	; $68
	db $FF,$FF,$FC,$FC,$FC,$FC,$FC,$FC ; $00,$00,$03,$03,$03,$03,$03,$03	; $69
	db $FC,$FC,$F8,$F8,$F8,$F8,$F8,$F8 ; $03,$03,$07,$07,$07,$07,$07,$07	; $6A           	
	db $F8,$F8,$F0,$F0,$F0,$F0,$F0,$F0 ; $07,$07,$0F,$0F,$0F,$0F,$0F,$0F	; $6B
	db $00,$00,$00,$00,$C1,$C1,$C1,$C1 ; $FF,$FF,$FF,$FF,$3E,$3E,$3E,$3E	; $6C
	db $C1,$C1,$C1,$C1,$83,$83,$83,$83 ; $3E,$3E,$3E,$3E,$7C,$7C,$7C,$7C	; $6D
	db $83,$83,$83,$83,$83,$83,$83,$83 ; $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C	; $6E
	db $81,$81,$81,$81,$FF,$FF,$FF,$FF ; $7E,$7E,$7E,$7E,$00,$00,$00,$00	; $6F
	db $FF,$FF,$1F,$1F,$1F,$1F,$1F,$1F ; $00,$00,$E0,$E0,$E0,$E0,$E0,$E0	; $70
	db $3F,$3F,$3F,$3F,$3F,$3F,$3F,$3F ; $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0	; $71
	db $FF,$FF,$FF,$FF,$FC,$FC,$00,$00 ; $00,$00,$00,$00,$03,$03,$FF,$FF	; $72
	db $00,$00,$FE,$FE,$FE,$FE,$FE,$FE ; $FF,$FF,$01,$01,$01,$01,$01,$01	; $73
	db $FE,$FE,$FE,$FE,$FC,$FC,$FC,$FC ; $01,$01,$01,$01,$03,$03,$03,$03	; $74
	db $FC,$FC,$FE,$FE,$FE,$FE,$FF,$FF ; $03,$03,$01,$01,$01,$01,$00,$00	; $75
	db $FF,$FF,$C7,$C7,$03,$03,$03,$03 ; $00,$00,$38,$38,$FC,$FC,$FC,$FC	; $76
	db $07,$07,$07,$07,$07,$07,$07,$07 ; $F8,$F8,$F8,$F8,$F8,$F8,$F8,$F8	; $77
	db $07,$07,$0F,$0F,$0F,$0F,$0F,$0F ; $F8,$F8,$F0,$F0,$F0,$F0,$F0,$F0	; $78
	db $00,$00,$00,$00,$00,$00,$FF,$FF ; $FF,$FF,$FF,$FF,$FF,$FF,$00,$00	; $79
	db $FF,$FF,$FE,$FE,$FE,$FE,$FC,$FC ; $00,$00,$01,$01,$01,$01,$03,$03	; $7A
	db $FC,$FC,$F0,$F0,$F0,$F0,$E0,$E0 ; $03,$03,$0F,$0F,$0F,$0F,$1F,$1F	; $7B
	db $E0,$E0,$C2,$C2,$8E,$8E,$0F,$0F ; $1F,$1F,$3D,$3D,$71,$71,$F0,$F0	; $7C
	db $1F,$1F,$3F,$3F,$FF,$FF,$FF,$FF ; $E0,$E0,$C0,$C0,$00,$00,$00,$00	; $7D
	db $0F,$0F,$3F,$3F,$3F,$3F,$3F,$3F ; $F0,$F0,$C0,$C0,$C0,$C0,$C0,$C0	; $7E
	db $3F,$3F,$3F,$3F,$3F,$3F,$3F,$3F ; $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0	; $7F
	db $0E,$0E,$0C,$0C,$00,$00,$00,$00 ; $F1,$F1,$F3,$F3,$FF,$FF,$FF,$FF	; $80
	db $81,$81,$FF,$FF,$FF,$FF,$FF,$FF ; $7E,$7E,$00,$00,$00,$00,$00,$00	; $81
	db $FF,$FF,$FF,$FF,$FF,$FF,$FC,$FC ; $00,$00,$00,$00,$00,$00,$03,$03	; $82
	db $F8,$F8,$F0,$F0,$E0,$E0,$C0,$C0 ; $07,$07,$0F,$0F,$1F,$1F,$3F,$3F	; $83
	db $04,$04,$0C,$0C,$3C,$3C,$FC,$FC ; $FB,$FB,$F3,$F3,$C3,$C3,$03,$03	; $84
	db $FC,$FC,$FC,$FC,$F8,$F8,$F8,$F8 ; $03,$03,$03,$03,$07,$07,$07,$07	; $85
	db $F8,$F8,$F8,$F8,$F8,$F8,$F0,$F0 ; $07,$07,$07,$07,$07,$07,$0F,$0F	; $86
	db $F0,$F0,$00,$00,$00,$00,$07,$07 ; $0F,$0F,$FF,$FF,$FF,$FF,$F8,$F8	; $87
	db $FC,$FC,$E0,$E0,$C1,$C1,$C1,$C1 ; $03,$03,$1F,$1F,$3E,$3E,$3E,$3E	; $88
	db $83,$83,$83,$83,$8F,$8F,$8F,$8F ; $7C,$7C,$7C,$7C,$70,$70,$70,$70	; $89
	db $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F ; $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0	; $8A
	db $00,$00,$00,$00,$1F,$1F,$1F,$1F ; $FF,$FF,$FF,$FF,$E0,$E0,$E0,$E0	; $8B
	db $1F,$1F,$1F,$1F,$1F,$1F,$1F,$1F ; $E0,$E0,$E0,$E0,$E0,$E0,$E0,$E0	; $8C
	db $3F,$3F,$3F,$3F,$3F,$3F,$3F,$3F ; $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0	; $8D
	db $3F,$3F,$3F,$3F,$3F,$3F,$7F,$7F ; $C0,$C0,$C0,$C0,$C0,$C0,$80,$80	; $8E
	db $7F,$7F,$FF,$FF,$FF,$FF,$FF,$FF ; $80,$80,$00,$00,$00,$00,$00,$00	; $8F
	db $3F,$3F,$0F,$0F,$07,$07,$07,$07 ; $C0,$C0,$F0,$F0,$F8,$F8,$F8,$F8	; $90
	db $0F,$0F,$0F,$0F,$3F,$3F,$FF,$FF ; $F0,$F0,$F0,$F0,$C0,$C0,$00,$00	; $91
	db $FE,$FE,$FE,$FE,$FE,$FE,$FE,$FE ; $01,$01,$01,$01,$01,$01,$01,$01	; $92
	db $00,$00,$00,$00,$FC,$FC,$FC,$FC ; $FF,$FF,$FF,$FF,$03,$03,$03,$03	; $93
	db $FC,$FC,$FC,$FC,$FC,$FC,$FC,$FC ; $03,$03,$03,$03,$03,$03,$03,$03	; $94
	db $FC,$FC,$FC,$FC,$F8,$F8,$F8,$F8 ; $03,$03,$03,$03,$07,$07,$07,$07	; $95
	db $F8,$F8,$F8,$F8,$F8,$F8,$F0,$F0 ; $07,$07,$07,$07,$07,$07,$0F,$0F	; $96
	db $F0,$F0,$01,$01,$01,$01,$07,$07 ; $0F,$0F,$FE,$FE,$FE,$FE,$F8,$F8	; $97
	db $F8,$F8,$E0,$E0,$C3,$C3,$C3,$C3 ; $07,$07,$1F,$1F,$3C,$3C,$3C,$3C	; $98
	db $07,$07,$07,$07,$0F,$0F,$0F,$0F ; $F8,$F8,$F8,$F8,$F0,$F0,$F0,$F0	; $99
	db $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F ; $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0	; $9A
	db $00,$00,$00,$00,$1F,$1F,$1F,$1F ; $FF,$FF,$FF,$FF,$E0,$E0,$E0,$E0	; $9B
	db $1F,$1F,$1F,$1F,$1F,$1F,$1F,$1F ; $E0,$E0,$E0,$E0,$E0,$E0,$E0,$E0	; $9C
	db $3F,$3F,$3F,$3F,$3F,$3F,$3F,$3F ; $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0	; $9D
	db $3F,$3F,$3F,$3F,$3F,$3F,$FF,$FF ; $C0,$C0,$C0,$C0,$C0,$C0,$00,$00	; $9E
	db $3F,$3F,$1F,$1F,$0F,$0F,$0F,$0F ; $C0,$C0,$E0,$E0,$F0,$F0,$F0,$F0	; $9F
	db $1F,$1F,$1F,$1F,$3F,$3F,$FF,$FF ; $E0,$E0,$E0,$E0,$C0,$C0,$00,$00	; $A0
	db $00,$00,$03,$03,$FF,$FF,$FF,$FF ; $FF,$FF,$FC,$FC,$00,$00,$00,$00	; $A1

logo_screen_data
	db $00,$00,$00,$00,$00,$00,$00,$00,$01,$08,$0E,$00,$00,$00,$00,$00,$00,$2C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$58,$5E,$64,$69,$70,$00,$00,$00,$00,$88,$90,$98,$9F
	db $00,$00,$00,$00,$00,$00,$00,$00,$02,$09,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$46,$4D,$00,$54,$59,$5F,$65,$6A,$71,$00,$00,$00,$00,$89,$91,$99,$A0
	db $00,$00,$00,$00,$00,$00,$00,$00,$03,$0A,$10,$15,$19,$1D,$21,$26,$2A,$2D,$00,$36,$3A,$3D,$00,$47,$4E,$00,$55,$5A,$00,$00,$6B,$72,$76,$7A,$7E,$82,$8A,$92,$9A,$00
	db $00,$00,$00,$00,$00,$00,$00,$00,$04,$0B,$11,$16,$1A,$1E,$22,$27,$2B,$2E,$32,$37,$3B,$3E,$41,$48,$4F,$00,$00,$5B,$60,$66,$6C,$73,$77,$7B,$7F,$83,$8B,$93,$9B,$A1
	db $00,$00,$00,$00,$00,$00,$00,$00,$05,$00,$12,$17,$1B,$1F,$23,$28,$00,$2F,$33,$38,$3C,$3F,$42,$49,$50,$00,$00,$00,$61,$67,$6D,$74,$78,$7C,$80,$84,$8C,$94,$9C,$00
	db $00,$00,$00,$00,$00,$00,$00,$00,$06,$0C,$13,$18,$1C,$20,$24,$29,$00,$30,$34,$39,$00,$40,$43,$4A,$51,$00,$56,$5C,$62,$68,$6E,$75,$79,$7D,$81,$85,$8D,$95,$9D,$00
	db $00,$00,$00,$00,$00,$00,$00,$00,$07,$0D,$14,$00,$00,$00,$25,$00,$00,$31,$35,$00,$00,$00,$44,$4B,$52,$00,$57,$5D,$63,$00,$6F,$00,$00,$00,$00,$86,$8E,$96,$9E,$00
	db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$45,$4C,$53,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$87,$8F,$97,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00

	align 256			; FREE $2659-$26FF

dycp_sine_table
; 64, 24, 0, 0, 4
	db $18,$1A,$1D,$1F,$21,$23,$25,$27,$29,$2B,$2C,$2D,$2E,$2F,$30,$30
	db $30,$30,$30,$2F,$2E,$2D,$2C,$2B,$29,$27,$25,$23,$21,$1F,$1D,$1A
	db $18,$16,$13,$11,$0F,$0D,$0B,$09,$07,$05,$04,$03,$02,$01,$00,$00
	db $00,$00,$00,$01,$02,$03,$04,$05,$07,$09,$0B,$0D,$0F,$11,$13,$16
	db $18,$1A,$1D,$1F,$21,$23,$25,$27,$29,$2B,$2C,$2D,$2E,$2F,$30,$30
	db $30,$30,$30,$2F,$2E,$2D,$2C,$2B,$29,$27,$25,$23,$21,$1F,$1D,$1A
	db $18,$16,$13,$11,$0F,$0D,$0B,$09,$07,$05,$04,$03,$02,$01,$00,$00
	db $00,$00,$00,$01,$02,$03,$04,$05,$07,$09,$0B,$0D,$0F,$11,$13,$16
	db $18,$1A,$1D,$1F,$21,$23,$25,$27,$29,$2B,$2C,$2D,$2E,$2F,$30,$30
	db $30,$30,$30,$2F,$2E,$2D,$2C,$2B,$29,$27,$25,$23,$21,$1F,$1D,$1A
	db $18,$16,$13,$11,$0F,$0D,$0B,$09,$07,$05,$04,$03,$02,$01,$00,$00
	db $00,$00,$00,$01,$02,$03,$04,$05,$07,$09,$0B,$0D,$0F,$11,$13,$16
	db $18,$1A,$1D,$1F,$21,$23,$25,$27,$29,$2B,$2C,$2D,$2E,$2F,$30,$30
	db $30,$30,$30,$2F,$2E,$2D,$2C,$2B,$29,$27,$25,$23,$21,$1F,$1D,$1A
	db $18,$16,$13,$11,$0F,$0D,$0B,$09,$07,$05,$04,$03,$02,$01,$00,$00
	db $00,$00,$00,$01,$02,$03,$04,$05,$07,$09,$0B,$0D,$0F,$11,$13,$16

	org $2800	; working font memory
work_font

	ds 2048

	org $3000	; 2X2 font
dycp_font
	db $FF,$E0,$DF,$BF,$BF,$BC,$BA,$BA	; $00 - @
	db $BA,$BA,$BC,$BF,$BF,$DF,$E0,$FF	; $01
	db $FF,$07,$E3,$F1,$F1,$31,$31,$31	; $02
	db $31,$23,$47,$FF,$F1,$E3,$07,$FF	; $03
	db $FF,$FE,$FE,$FC,$FC,$FB,$FB,$F7	; $04 - A
	db $F0,$EF,$EF,$DF,$DF,$BF,$BF,$FF      ; $05
	db $FF,$7F,$7F,$3F,$3F,$1F,$1F,$8F	; $06
	db $0F,$C7,$C7,$E3,$E3,$F1,$F1,$FF      ; $07
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF	; $08 - B
	db $80,$BF,$BF,$BF,$BF,$BF,$80,$FF      ; $09
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3	; $0A
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $0B
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF	; $0C - C
	db $BF,$BF,$BF,$BF,$BF,$DF,$E0,$FF      ; $0D
	db $FF,$07,$E3,$F1,$FF,$FF,$FF,$FF	; $0E
	db $FF,$FF,$FF,$FF,$F1,$E3,$07,$FF      ; $0F
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF      ; $10 - D
	db $BF,$BF,$BF,$BF,$BF,$BF,$80,$FF      ; $11    
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$F1      ; $12
	db $F1,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $13    
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF      ; $14 - E
	db $80,$BF,$BF,$BF,$BF,$BF,$80,$FF      ; $15    
	db $FF,$01,$F1,$F1,$FF,$FF,$FF,$FF      ; $16
	db $7F,$FF,$FF,$FF,$F1,$F1,$01,$FF      ; $17    
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF      ; $18 - F
	db $80,$BF,$BF,$BF,$BF,$BF,$BF,$FF      ; $19    
	db $FF,$01,$F1,$F1,$FF,$FF,$FF,$FF      ; $1A
	db $7F,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $1B    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF      ; $1C - G
	db $BE,$BF,$BF,$BF,$BF,$DF,$E0,$FF      ; $1D    
	db $FF,$07,$E3,$F1,$FF,$FF,$FF,$FF      ; $1E
	db $01,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $1F    
	db $FF,$BF,$BF,$BF,$BF,$BF,$BF,$BF      ; $20 - H
	db $80,$BF,$BF,$BF,$BF,$BF,$BF,$FF      ; $21    
	db $FF,$F1,$F1,$F1,$F1,$F1,$F1,$F1      ; $22
	db $01,$F1,$F1,$F1,$F1,$F1,$F1,$FF      ; $23    
	db $FF,$F8,$FE,$FE,$FE,$FE,$FE,$FE      ; $24 - I
	db $FE,$FE,$FE,$FE,$FE,$FE,$F8,$FF      ; $25    
	db $FF,$1F,$7F,$7F,$7F,$7F,$7F,$7F      ; $26
	db $7F,$7F,$7F,$7F,$7F,$7F,$1F,$FF      ; $27    
	db $FF,$80,$FF,$FF,$FF,$FF,$FF,$FF      ; $28 - J
	db $FE,$FF,$FF,$FF,$BF,$DF,$E0,$FF      ; $29    
	db $FF,$01,$F1,$F1,$F1,$F1,$F1,$F1      ; $2A
	db $01,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $2B    
	db $FF,$BF,$BF,$BF,$BF,$BF,$BE,$80      ; $2C - K
	db $80,$BE,$BF,$BF,$BF,$BF,$BF,$FF      ; $2D    
	db $FF,$F1,$E3,$C7,$8F,$1F,$3F,$7F      ; $2E
	db $7F,$3F,$1F,$8F,$C7,$E3,$F1,$FF      ; $2F    
	db $FF,$BF,$BF,$BF,$BF,$BF,$BF,$BF      ; $30 - L
	db $BF,$BF,$BF,$BF,$BF,$BF,$80,$FF      ; $31    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $32
	db $FF,$FF,$FF,$FF,$F1,$F1,$01,$FF      ; $33    
	db $FF,$BF,$9F,$AF,$B7,$BB,$BC,$BE      ; $34 - M
	db $BF,$BF,$BF,$BF,$BF,$BF,$BF,$FF      ; $35    
	db $FF,$F1,$E1,$C1,$81,$11,$31,$71      ; $36
	db $F1,$F1,$F1,$F1,$F1,$F1,$F1,$FF      ; $37    
	db $FF,$BF,$9F,$8F,$87,$A3,$B1,$B8      ; $38 - N
	db $BC,$BE,$BF,$BF,$BF,$BF,$BF,$FF      ; $39    
	db $FF,$F1,$F1,$F1,$F1,$F1,$F1,$F1      ; $3A
	db $71,$31,$11,$81,$C1,$E1,$F1,$FF      ; $3B    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF      ; $3C - O
	db $BF,$BF,$BF,$BF,$BF,$DF,$E0,$FF      ; $3D    
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$F1      ; $3E
	db $F1,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $3F    
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF      ; $40 - P
	db $80,$BF,$BF,$BF,$BF,$BF,$BF,$FF	; $41
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3	; $42
	db $07,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $43
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF	; $44 - Q
	db $BF,$BF,$BF,$BF,$DF,$E0,$FF,$FF      ; $45
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$F1	; $46
	db $F1,$F1,$11,$83,$C7,$23,$F1,$FF      ; $47
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF	; $48 - R
	db $80,$BE,$BF,$BF,$BF,$BF,$BF,$FF      ; $49
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3	; $4A
	db $0F,$3F,$1F,$8F,$C7,$E3,$F1,$FF      ; $4B
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$DF	; $4C - S
	db $E0,$FF,$FF,$FF,$BF,$DF,$E0,$FF      ; $4D
	db $FF,$07,$E3,$F1,$FF,$FF,$FF,$FF	; $4E
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $4F
	db $FF,$80,$FE,$FE,$FE,$FE,$FE,$FE      ; $50 - T  
	db $FE,$FE,$FE,$FE,$FE,$FE,$FE,$FF      ; $51    
	db $FF,$01,$7F,$7F,$7F,$7F,$7F,$7F      ; $52
	db $7F,$7F,$7F,$7F,$7F,$7F,$7F,$FF      ; $53    
	db $FF,$BF,$BF,$BF,$BF,$BF,$BF,$BF      ; $54 - U  
	db $BF,$BF,$BF,$BF,$BF,$DF,$E0,$FF      ; $55    
	db $FF,$F1,$F1,$F1,$F1,$F1,$F1,$F1      ; $56
	db $F1,$F1,$F1,$F1,$F1,$F1,$01,$FF      ; $57    
	db $FF,$BF,$BF,$DF,$DF,$EF,$EF,$F7      ; $58 - V  
	db $F7,$FB,$FB,$FC,$FC,$FE,$FE,$FF      ; $59    
	db $FF,$F1,$F1,$E3,$E3,$C7,$C7,$8F      ; $5A
	db $8F,$1F,$1F,$3F,$3F,$7F,$7F,$FF      ; $5B    
	db $FF,$BF,$BF,$BF,$BF,$BF,$BF,$BF      ; $5C - W  
	db $BE,$BC,$BB,$B7,$AF,$9F,$BF,$FF      ; $5D    
	db $FF,$F1,$F1,$F1,$F1,$F1,$F1,$F1      ; $5E
	db $71,$31,$11,$81,$C1,$E1,$F1,$FF      ; $5F    
	db $FF,$BF,$DF,$EF,$F7,$FB,$FC,$FC      ; $60 - X  
	db $FC,$FC,$FB,$F7,$EF,$DF,$BF,$FF      ; $61    
	db $FF,$F1,$E3,$C7,$8F,$1F,$3F,$7F      ; $62
	db $7F,$3F,$1F,$8F,$C7,$E3,$F1,$FF      ; $63    
	db $FF,$BF,$DF,$EF,$F7,$FB,$FC,$FE      ; $64 - Y  
	db $FE,$FE,$FE,$FE,$FE,$FE,$FE,$FF      ; $65    
	db $FF,$F1,$E3,$C7,$8F,$1F,$3F,$7F      ; $66
	db $7F,$7F,$7F,$7F,$7F,$7F,$7F,$FF      ; $67    
	db $FF,$80,$FF,$FF,$FF,$FF,$FF,$FE      ; $68 - Z  
	db $FC,$F8,$F1,$E3,$C7,$8F,$80,$FF      ; $69    
	db $FF,$01,$F1,$E3,$C7,$8F,$1F,$3F      ; $6A
	db $7F,$FF,$FF,$FF,$FF,$FF,$01,$FF      ; $6B    
	db $FF,$FC,$FC,$FC,$FC,$FC,$FC,$FC      ; $6C - [   
	db $FC,$FC,$FC,$FC,$FC,$FC,$FC,$FF      ; $6D    
	db $FF,$3F,$FF,$FF,$FF,$FF,$FF,$FF      ; $6E
	db $FF,$FF,$FF,$FF,$FF,$FF,$3F,$FF      ; $6F    
	db $FF,$FE,$FD,$FD,$FB,$FB,$F7,$F7      ; $70 - pound   
	db $E0,$F7,$EF,$EF,$DF,$DF,$80,$FF      ; $71    
	db $FF,$7F,$BF,$9F,$8F,$FF,$FF,$FF      ; $72
	db $07,$FF,$FF,$FF,$FF,$FF,$01,$FF      ; $73    
	db $FF,$FC,$FF,$FF,$FF,$FF,$FF,$FF      ; $74 - ]   
	db $FF,$FF,$FF,$FF,$FF,$FF,$FC,$FF      ; $75    
	db $FF,$3F,$3F,$3F,$3F,$3F,$3F,$3F      ; $76
	db $3F,$3F,$3F,$3F,$3F,$3F,$3F,$FF      ; $77    
	db $FF,$FE,$FC,$F8,$F2,$E6,$FE,$FE      ; $78 - up arrow   
	db $FE,$FE,$FE,$FE,$FE,$FE,$FE,$FF      ; $79    
	db $FF,$7F,$3F,$1F,$4F,$67,$7F,$7F      ; $7A
	db $7F,$7F,$7F,$7F,$7F,$7F,$7F,$FF      ; $7B    
	db $FF,$FF,$FF,$FB,$F3,$E7,$CF,$80      ; $7C - left arrow   
	db $80,$CF,$E7,$F3,$FB,$FF,$FF,$FF      ; $7D    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$01      ; $7E
	db $01,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $7F    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF	; $80 - space
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $81
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF	; $82
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $83
	db $FF,$FE,$FE,$FE,$FE,$FE,$FE,$FE	; $84 - !
	db $FE,$FE,$FE,$FF,$FF,$FE,$FE,$FF      ; $85
	db $FF,$7F,$7F,$7F,$7F,$7F,$7F,$7F	; $86
	db $7F,$7F,$7F,$FF,$FF,$7F,$7F,$FF      ; $87
	db $FF,$F3,$E7,$E7,$FF,$FF,$FF,$FF	; $88 - "
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $89
	db $FF,$CF,$9F,$9F,$FF,$FF,$FF,$FF	; $8A
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $8B
	db $FF,$F3,$F3,$F3,$F3,$E7,$80,$E7	; $8C - #
	db $E7,$80,$E7,$CF,$CF,$CF,$CF,$FF      ; $8D
	db $FF,$F3,$F3,$F3,$F3,$E7,$01,$E7	; $8E
	db $E7,$01,$E7,$CF,$CF,$CF,$CF,$FF      ; $8F
	db $FF,$FE,$E0,$DE,$BE,$BE,$BE,$DE      ; $90 - $  
	db $E0,$FE,$FE,$BE,$DE,$E0,$FE,$FF      ; $91    
	db $FF,$7F,$07,$63,$71,$7F,$7F,$7F      ; $92
	db $07,$63,$71,$71,$63,$07,$7F,$FF      ; $93    
	db $FF,$FF,$8F,$8F,$8F,$FF,$FF,$FE      ; $94 - %   
	db $FC,$F8,$F1,$E3,$C7,$8F,$FF,$FF      ; $95    
	db $FF,$FF,$F1,$E3,$C7,$8F,$1F,$3F      ; $96
	db $7F,$FF,$FF,$F1,$F1,$F1,$FF,$FF      ; $97    
	db $FF,$FC,$FB,$F7,$F7,$FB,$FD,$FE      ; $98 - &  
	db $F8,$F7,$EF,$DF,$DF,$E7,$F8,$FF      ; $99    
	db $FF,$1F,$8F,$C7,$C7,$8F,$1F,$7F      ; $9A
	db $3F,$1F,$91,$C3,$E7,$83,$71,$FF      ; $9B    
	db $FF,$FF,$FE,$FE,$FF,$FF,$FF,$FF      ; $9C - '  
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $9D    
	db $FF,$3F,$7F,$7F,$FF,$FF,$FF,$FF      ; $9E - '  
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $9F    
	db $FF,$FF,$FF,$FF,$FE,$FE,$FC,$FC      ; $A0 - (   
	db $FC,$FC,$FE,$FE,$FF,$FF,$FF,$FF      ; $A1    
	db $FF,$DF,$9F,$3F,$7F,$7F,$7F,$FF      ; $A2
	db $FF,$7F,$7F,$7F,$3F,$9F,$DF,$FF      ; $A3    
	db $FF,$FB,$F9,$FC,$FE,$FE,$FE,$FF      ; $A4 - )   
	db $FF,$FE,$FE,$FE,$FC,$F9,$FB,$FF      ; $A5    
	db $FF,$FF,$FF,$FF,$7F,$7F,$3F,$3F      ; $A6
	db $3F,$3F,$7F,$7F,$FF,$FF,$FF,$FF      ; $A7    
	db $FF,$FE,$DE,$EE,$F6,$FA,$FC,$FE      ; $A8 - *  
	db $80,$FD,$FB,$F7,$EF,$DF,$FF,$FF      ; $A9    
	db $FF,$FF,$FB,$F7,$EF,$DF,$BF,$01      ; $AA
	db $7F,$3F,$5F,$6F,$77,$7B,$7F,$FF      ; $AB    
	db $FF,$FF,$FE,$FE,$FE,$FE,$FE,$C0      ; $AC - +  
	db $C0,$FE,$FE,$FE,$FE,$FE,$FF,$FF      ; $AD    
	db $FF,$FF,$7F,$7F,$7F,$7F,$7F,$03      ; $AE
	db $03,$7F,$7F,$7F,$7F,$7F,$FF,$FF      ; $AF    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $B0 - , 
	db $FF,$FF,$FF,$FF,$FE,$FE,$FC,$FF      ; $B1    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $B2
	db $FF,$FF,$FF,$FF,$7F,$7F,$FF,$FF      ; $B3    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$C0      ; $B4 - -  
	db $C0,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $B5    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$03      ; $B6
	db $03,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $B7    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $B8 - .  
	db $FF,$FF,$FF,$FF,$FF,$FE,$FE,$FF      ; $B9    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $BA
	db $FF,$FF,$FF,$FF,$FF,$7F,$7F,$FF      ; $BB    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FE      ; $BC - /  
	db $FC,$F8,$F1,$E3,$C7,$8F,$FF,$FF      ; $BD    
	db $FF,$FF,$F1,$E3,$C7,$8F,$1F,$3F      ; $BE
	db $7F,$FF,$FF,$FF,$FF,$FF,$FF,$FF      ; $BF    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF	; $C0 - 0
	db $BE,$BD,$BB,$B7,$AF,$DF,$E0,$FF	; $C1
	db $FF,$07,$E3,$F1,$E1,$D1,$B1,$71	; $C2
	db $F1,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $C3
	db $FF,$FE,$FC,$F8,$F2,$E6,$FE,$FE	; $C4 - 1
	db $FE,$FE,$FE,$FE,$FE,$FE,$F8,$FF      ; $C5
	db $FF,$7F,$7F,$7F,$7F,$7F,$7F,$7F	; $C6
	db $7F,$7F,$7F,$7F,$7F,$7F,$1F,$FF      ; $C7
	db $FF,$E0,$DF,$BF,$FF,$FF,$FF,$FF	; $C8 - 2
	db $FF,$FF,$FE,$F9,$E7,$9F,$80,$FF      ; $C9
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3	; $CA
	db $C7,$9F,$7F,$FF,$F1,$F1,$01,$FF      ; $CB
	db $FF,$E0,$DF,$BF,$FF,$FF,$FF,$FF	; $CC - 3
	db $FE,$FF,$FF,$FF,$BF,$DF,$E0,$FF      ; $CD
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3	; $CE
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $CF
	db $FF,$FF,$FE,$FD,$FB,$F7,$EF,$DF      ; $D0 - 4  
	db $80,$FF,$FF,$FF,$FF,$FF,$FE,$FF      ; $D1    
	db $FF,$1F,$9F,$9F,$9F,$9F,$9F,$9F      ; $D2
	db $01,$9F,$9F,$9F,$9F,$9F,$07,$FF      ; $D3    
	db $FF,$80,$BF,$BF,$BF,$BF,$BF,$BF      ; $D4 - 5  
	db $80,$FF,$FF,$FF,$BF,$DF,$E0,$FF      ; $D5    
	db $FF,$01,$F1,$F1,$FF,$FF,$FF,$FF      ; $D6
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $D7    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$BF      ; $D8 - 6  
	db $80,$BF,$BF,$BF,$BF,$DF,$E0,$FF      ; $D9    
	db $FF,$07,$E3,$F1,$FF,$FF,$FF,$FF      ; $DA - 6  
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $DB    
	db $FF,$80,$FF,$FF,$FF,$FF,$FE,$FE      ; $DC - 7  
	db $F8,$FE,$FE,$FE,$FE,$FE,$FE,$FF      ; $DD    
	db $FF,$01,$E3,$C7,$8F,$1F,$3F,$7F      ; $DE
	db $1F,$7F,$7F,$7F,$7F,$7F,$7F,$FF      ; $DF    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$DF      ; $E0 - 8  
	db $E0,$DF,$BF,$BF,$BF,$DF,$E0,$FF      ; $E1    
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3      ; $E2
	db $07,$E3,$F1,$F1,$F1,$E3,$07,$FF      ; $E3    
	db $FF,$E0,$DF,$BF,$BF,$BF,$BF,$DF      ; $E4 - 9  
	db $E0,$FF,$FF,$FF,$BF,$DF,$E0,$FF      ; $E5    
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$F1      ; $E6
	db $01,$F1,$F1,$F1,$F1,$E3,$07,$FF      ; $E7    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FE      ; $E8 - :  
	db $FE,$FF,$FF,$FF,$FE,$FE,$FF,$FF      ; $E9    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$7F      ; $EA
	db $7F,$FF,$FF,$FF,$7F,$7F,$FF,$FF      ; $EB    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FE      ; $EC - ;  
	db $FE,$FF,$FF,$FF,$FE,$FE,$FC,$FF      ; $ED    
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$7F      ; $EE
	db $7F,$FF,$FF,$FF,$7F,$7F,$FF,$FF      ; $EF    
	db $FF,$FF,$FF,$FF,$FE,$F9,$E7,$9F      ; $F0 - <   
	db $9F,$E7,$F9,$FE,$FF,$FF,$FF,$FF      ; $F1    
	db $FF,$F9,$E7,$9F,$7F,$FF,$FF,$FF      ; $F2
	db $FF,$FF,$FF,$7F,$9F,$E7,$F9,$FF      ; $F3    
	db $FF,$FF,$FF,$FF,$FF,$C0,$C0,$FF      ; $F4 - =  
	db $FF,$C0,$C0,$FF,$FF,$FF,$FF,$FF      ; $F5    
	db $FF,$FF,$FF,$FF,$FF,$03,$03,$FF      ; $F6
	db $FF,$03,$03,$FF,$FF,$FF,$FF,$FF      ; $F7    
	db $FF,$9F,$E7,$F9,$FE,$FF,$FF,$FF      ; $F8 - >  
	db $FF,$FF,$FF,$FE,$F9,$E7,$9F,$FF      ; $F9    
	db $FF,$FF,$FF,$FF,$7F,$9F,$E7,$F9      ; $FA
	db $F9,$E7,$9F,$7F,$FF,$FF,$FF,$FF      ; $FB    
	db $FF,$E0,$DF,$BF,$FF,$FF,$FF,$FF      ; $FC - ?  
	db $FF,$FE,$FE,$FF,$FF,$FE,$FE,$FF      ; $FD    
	db $FF,$07,$E3,$F1,$F1,$F1,$F1,$E3      ; $FE
	db $07,$7F,$7F,$FF,$FF,$7F,$7F,$FF      ; $FF    

logo_scroll_pos
	db 0,0,1,1,2,2,3,4,4,5,5,6,6,7,7,0,0,1,2,2,3,3,4,4,5,5,5,6,6,7,7,0,0,1,1,1,2,2,2,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,7
	db 7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,2,2,2,1,1,1,0,0,7,7,6,6,5,5,5,4,4,3,3,2,2,1,0,0,7,7,6,6,5,5,4,4,3,2,2,1,1,0
	db 0,7,6,6,5,5,4,3,3,2,2,1,1,0,0,7,7,6,5,5,4,4,3,3,2,2,2,1,1,0,0,7,7,6,6,6,5,5,5,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,0,0,1,1,2,2,2,3,3,4,4,5,5,6,7,7,0,0,1,1,2,2,3,3,4,5,5,6,6,7

logo_copy_pos
	db 4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2
	db 2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4
	db 4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7
	db 7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5

scroll_text
	db $08,$05,$0C,$0C,$0F,$20,$07,$0F,$0F,$04,$20,$10,$05,$0F,$10,$0C
	db $05,$2E,$20,$07,$05,$12,$0C,$09,$03,$1A,$05,$12,$20,$08,$05,$12
	db $05,$20,$17,$09,$14,$08,$20,$08,$09,$13,$20,$0E,$05,$18,$14,$20
	db $01,$14,$14,$05,$0D,$10,$14,$20,$14,$0F,$20,$02,$0F,$12,$05,$20
	db $19,$0F,$15,$20,$14,$0F,$20,$04,$05,$01,$14,$08,$2E,$20,$14,$08
	db $0F,$15,$13,$01,$0E,$04,$20,$14,$09,$0D,$05,$13,$20,$13,$05,$05
	db $0E,$20,$05,$06,$06,$05,$03,$14,$13,$20,$09,$0E,$20,$11,$15,$05
	db $13,$14,$09,$0F,$0E,$01,$02,$0C,$05,$20,$11,$15,$01,$0C,$09,$14
	db $19,$2E,$20,$14,$08,$01,$14,$27,$13,$20,$0D,$19,$20,$17,$05,$01
	db $10,$0F,$0E,$20,$0F,$06,$20,$03,$08,$0F,$09,$03,$05,$2E,$20,$08
	db $0F,$10,$05,$20,$19,$0F,$15,$20,$01,$12,$05,$20,$0E,$0F,$14,$20
	db $14,$05,$01,$12,$19,$20,$05,$19,$05,$04,$20,$19,$05,$14,$2E,$20
	db $0F,$14,$08,$05,$12,$17,$09,$13,$05,$20,$19,$0F,$15,$20,$17,$0F
	db $0E,$27,$14,$20,$13,$05,$05,$20,$14,$08,$05,$20,$07,$12,$05,$05
	db $14,$09,$0E,$07,$13,$2E,$20,$07,$12,$05,$05,$14,$13,$20,$09,$0E
	db $20,$0E,$0F,$20,$10,$01,$12,$14,$09,$03,$15,$0C,$01,$12,$20,$0F
	db $12,$04,$05,$12,$20,$14,$0F,$20,$03,$13,$01,$02,$0F,$2C,$20,$0C
	db $15,$03,$01,$2C,$20,$13,$09,$1A,$2C,$20,$0D,$0D,$13,$2C,$20,$07
	db $05,$0F,$12,$07,$05,$2C,$20,$0D,$01,$04,$2C,$20,$0B,$09,$03,$08
	db $19,$2C,$20,$13,$16,$13,$2C,$20,$04,$05,$07,$01,$15,$13,$13,$2C
	db $20,$35,$14,$01,$12,$02,$15,$03,$0B,$2C,$20,$14,$0C,$03,$2C,$20
	db $14,$2E,$0D,$2E,$12,$2C,$20,$04,$0F,$15,$07,$2C,$20,$0E,$0F,$0A
	db $05,$05,$05,$2C,$20,$02,$13,$1A,$2C,$20,$03,$08,$12,$0F,$0E,$0F
	db $13,$2C,$20,$03,$08,$09,$03,$0B,$05,$0E,$2C,$20,$13,$04,$17,$2C
	db $20,$03,$01,$12,$12,$09,$0F,$0E,$2C,$20,$0A,$01,$0D,$05,$13,$04
	db $2C,$20,$0A,$01,$0D,$05,$13,$03,$2C,$20,$03,$08,$01,$12,$0C,$05
	db $0D,$01,$07,$0E,$05,$2C,$20,$0C,$01,$16,$09,$0E,$01,$2C,$20,$07
	db $01,$09,$01,$2C,$20,$09,$13,$14,$16,$01,$0E,$16,$2C,$20,$13,$10
	db $05,$0B,$14,$12,$0F,$2C,$20,$0D,$01,$0A,$09,$0B,$05,$19,$12,$09
	db $03,$2C,$20,$03,$12,$0F,$03,$0B,$20,$26,$20,$01,$0C,$0C,$20,$0F
	db $14,$08,$05,$12,$20,$10,$01,$0C,$13,$20,$09,$20,$06,$0F,$12,$07
	db $0F,$14,$20,$14,$0F,$20,$0D,$05,$0E,$14,$09,$0F,$0E,$20,$0F,$16
	db $05,$12,$20,$00,$20,$10,$0C,$15,$13,$34,$17,$0F,$12,$0C,$04,$2E
	db $03,$0F,$0D,$20,$20,$15,$0E,$06,$0F,$12,$14,$15,$0E,$01,$14,$05
	db $0C,$19,$2C,$20,$09,$20,$12,$01,$0E,$20,$0F,$15,$14,$20,$0F,$06
	db $20,$09,$04,$05,$01,$13,$20,$17,$08,$01,$14,$20,$14,$0F,$20,$02
	db $0F,$12,$05,$20,$19,$0F,$15,$20,$17,$09,$14,$08,$20,$06,$0F,$12
	db $20,$0D,$0F,$12,$05,$2C,$20,$14,$08,$05,$12,$05,$06,$0F,$12,$05
	db $20,$09,$20,$12,$05,$13,$14,$01,$12,$14,$20,$14,$08,$09,$13,$20
	db $03,$12,$2A,$10,$2E,$20,$08,$01,$16,$05,$20,$01,$0E,$0F,$14,$08
	db $05,$12,$20,$07,$0F,$0F,$04,$20,$12,$05,$01,$04,$2E,$20,$3A,$04
	db $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$39,$20,$20,$20,$38
	db $20,$20,$20,$37,$20,$20,$20,$36,$20,$20,$20,$35,$20,$20,$20,$34
	db $20,$20,$20,$33,$20,$20,$20,$32,$20,$20,$20,$31,$20,$20,$20,$08
	db $05,$12,$05,$20,$17,$05,$20,$07,$0F,$20,$01,$07,$01,$09,$0E,$21
	db $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
scroll_text_end				equ		*

copy_dycp_data
;	dec $FF19
	lda $1C01+ 9*40
	sta $1C00+ 9*40
	sta $1C00+11*40
	sta $1C00+13*40
	sta $1C00+15*40
	lda $1C02+ 9*40
	sta $1C01+ 9*40
	sta $1C01+11*40
	sta $1C01+13*40
	sta $1C01+15*40
	lda $1C03+ 9*40
	sta $1C02+ 9*40
	sta $1C02+11*40
	sta $1C02+13*40
	sta $1C02+15*40
	lda $1C04+ 9*40
	sta $1C03+ 9*40
	sta $1C03+11*40
	sta $1C03+13*40
	sta $1C03+15*40
	lda $1C05+ 9*40
	sta $1C04+ 9*40
	sta $1C04+11*40
	sta $1C04+13*40
	sta $1C04+15*40
	lda $1C06+ 9*40
	sta $1C05+ 9*40
	sta $1C05+11*40
	sta $1C05+13*40
	sta $1C05+15*40
	lda $1C07+ 9*40
	sta $1C06+ 9*40
	sta $1C06+11*40
	sta $1C06+13*40
	sta $1C06+15*40
	lda $1C08+ 9*40
	sta $1C07+ 9*40
	sta $1C07+11*40
	sta $1C07+13*40
	sta $1C07+15*40
	lda $1C09+ 9*40
	sta $1C08+ 9*40
	sta $1C08+11*40
	sta $1C08+13*40
	sta $1C08+15*40
	lda $1C0A+ 9*40
	sta $1C09+ 9*40
	sta $1C09+11*40
	sta $1C09+13*40
	sta $1C09+15*40
	lda $1C0B+ 9*40
	sta $1C0A+ 9*40
	sta $1C0A+11*40
	sta $1C0A+13*40
	sta $1C0A+15*40
	lda $1C0C+ 9*40
	sta $1C0B+ 9*40
	sta $1C0B+11*40
	sta $1C0B+13*40
	sta $1C0B+15*40
	lda $1C0D+ 9*40
	sta $1C0C+ 9*40
	sta $1C0C+11*40
	sta $1C0C+13*40
	sta $1C0C+15*40
	lda $1C0E+ 9*40
	sta $1C0D+ 9*40
	sta $1C0D+11*40
	sta $1C0D+13*40
	sta $1C0D+15*40
	lda $1C0F+ 9*40
	sta $1C0E+ 9*40
	sta $1C0E+11*40
	sta $1C0E+13*40
	sta $1C0E+15*40
	lda $1C10+ 9*40
	sta $1C0F+ 9*40
	sta $1C0F+11*40
	sta $1C0F+13*40
	sta $1C0F+15*40
	lda $1C11+ 9*40
	sta $1C10+ 9*40
	sta $1C10+11*40
	sta $1C10+13*40
	sta $1C10+15*40
	lda $1C12+ 9*40
	sta $1C11+ 9*40
	sta $1C11+11*40
	sta $1C11+13*40
	sta $1C11+15*40
	lda $1C13+ 9*40
	sta $1C12+ 9*40
	sta $1C12+11*40
	sta $1C12+13*40
	sta $1C12+15*40
	lda $1C14+ 9*40
	sta $1C13+ 9*40
	sta $1C13+11*40
	sta $1C13+13*40
	sta $1C13+15*40
	lda $1C15+ 9*40
	sta $1C14+ 9*40
	sta $1C14+11*40
	sta $1C14+13*40
	sta $1C14+15*40
	lda $1C16+ 9*40
	sta $1C15+ 9*40
	sta $1C15+11*40
	sta $1C15+13*40
	sta $1C15+15*40
	lda $1C17+ 9*40
	sta $1C16+ 9*40
	sta $1C16+11*40
	sta $1C16+13*40
	sta $1C16+15*40
	lda $1C18+ 9*40
	sta $1C17+ 9*40
	sta $1C17+11*40
	sta $1C17+13*40
	sta $1C17+15*40
	lda $1C19+ 9*40
	sta $1C18+ 9*40
	sta $1C18+11*40
	sta $1C18+13*40
	sta $1C18+15*40
	lda $1C1A+ 9*40
	sta $1C19+ 9*40
	sta $1C19+11*40
	sta $1C19+13*40
	sta $1C19+15*40
	lda $1C1B+ 9*40
	sta $1C1A+ 9*40
	sta $1C1A+11*40
	sta $1C1A+13*40
	sta $1C1A+15*40
	lda $1C1C+ 9*40
	sta $1C1B+ 9*40
	sta $1C1B+11*40
	sta $1C1B+13*40
	sta $1C1B+15*40
	lda $1C1D+ 9*40
	sta $1C1C+ 9*40
	sta $1C1C+11*40
	sta $1C1C+13*40
	sta $1C1C+15*40
	lda $1C1E+ 9*40
	sta $1C1D+ 9*40
	sta $1C1D+11*40
	sta $1C1D+13*40
	sta $1C1D+15*40
	lda $1C1F+ 9*40
	sta $1C1E+ 9*40
	sta $1C1E+11*40
	sta $1C1E+13*40
	sta $1C1E+15*40
	lda $1C20+ 9*40
	sta $1C1F+ 9*40
	sta $1C1F+11*40
	sta $1C1F+13*40
	sta $1C1F+15*40
	lda $1C21+ 9*40
	sta $1C20+ 9*40
	sta $1C20+11*40
	sta $1C20+13*40
	sta $1C20+15*40
	lda $1C22+ 9*40
	sta $1C21+ 9*40
	sta $1C21+11*40
	sta $1C21+13*40
	sta $1C21+15*40
	lda $1C23+ 9*40
	sta $1C22+ 9*40
	sta $1C22+11*40
	sta $1C22+13*40
	sta $1C22+15*40
	lda $1C24+ 9*40
	sta $1C23+ 9*40
	sta $1C23+11*40
	sta $1C23+13*40
	sta $1C23+15*40
	lda $1C25+ 9*40
	sta $1C24+ 9*40
	sta $1C24+11*40
	sta $1C24+13*40
	sta $1C24+15*40
	lda $1C26+ 9*40
	sta $1C25+ 9*40
	sta $1C25+11*40
	sta $1C25+13*40
	sta $1C25+15*40
	lda $1C27+ 9*40
	sta $1C26+ 9*40
	sta $1C26+11*40
	sta $1C26+13*40
	sta $1C26+15*40
	lda $1C01+10*40
	sta $1C00+10*40
	sta $1C00+12*40
	sta $1C00+14*40
	sta $1C00+16*40
	lda $1C02+10*40
	sta $1C01+10*40
	sta $1C01+12*40
	sta $1C01+14*40
	sta $1C01+16*40
	lda $1C03+10*40
	sta $1C02+10*40
	sta $1C02+12*40
	sta $1C02+14*40
	sta $1C02+16*40
	lda $1C04+10*40
	sta $1C03+10*40
	sta $1C03+12*40
	sta $1C03+14*40
	sta $1C03+16*40
	lda $1C05+10*40
	sta $1C04+10*40
	sta $1C04+12*40
	sta $1C04+14*40
	sta $1C04+16*40
	lda $1C06+10*40
	sta $1C05+10*40
	sta $1C05+12*40
	sta $1C05+14*40
	sta $1C05+16*40
	lda $1C07+10*40
	sta $1C06+10*40
	sta $1C06+12*40
	sta $1C06+14*40
	sta $1C06+16*40
	lda $1C08+10*40
	sta $1C07+10*40
	sta $1C07+12*40
	sta $1C07+14*40
	sta $1C07+16*40
	lda $1C09+10*40
	sta $1C08+10*40
	sta $1C08+12*40
	sta $1C08+14*40
	sta $1C08+16*40
	lda $1C0A+10*40
	sta $1C09+10*40
	sta $1C09+12*40
	sta $1C09+14*40
	sta $1C09+16*40
	lda $1C0B+10*40
	sta $1C0A+10*40
	sta $1C0A+12*40
	sta $1C0A+14*40
	sta $1C0A+16*40
	lda $1C0C+10*40
	sta $1C0B+10*40
	sta $1C0B+12*40
	sta $1C0B+14*40
	sta $1C0B+16*40
	lda $1C0D+10*40
	sta $1C0C+10*40
	sta $1C0C+12*40
	sta $1C0C+14*40
	sta $1C0C+16*40
	lda $1C0E+10*40
	sta $1C0D+10*40
	sta $1C0D+12*40
	sta $1C0D+14*40
	sta $1C0D+16*40
	lda $1C0F+10*40
	sta $1C0E+10*40
	sta $1C0E+12*40
	sta $1C0E+14*40
	sta $1C0E+16*40
	lda $1C10+10*40
	sta $1C0F+10*40
	sta $1C0F+12*40
	sta $1C0F+14*40
	sta $1C0F+16*40
	lda $1C11+10*40
	sta $1C10+10*40
	sta $1C10+12*40
	sta $1C10+14*40
	sta $1C10+16*40
	lda $1C12+10*40
	sta $1C11+10*40
	sta $1C11+12*40
	sta $1C11+14*40
	sta $1C11+16*40
	lda $1C13+10*40
	sta $1C12+10*40
	sta $1C12+12*40
	sta $1C12+14*40
	sta $1C12+16*40
	lda $1C14+10*40
	sta $1C13+10*40
	sta $1C13+12*40
	sta $1C13+14*40
	sta $1C13+16*40
	lda $1C15+10*40
	sta $1C14+10*40
	sta $1C14+12*40
	sta $1C14+14*40
	sta $1C14+16*40
	lda $1C16+10*40
	sta $1C15+10*40
	sta $1C15+12*40
	sta $1C15+14*40
	sta $1C15+16*40
	lda $1C17+10*40
	sta $1C16+10*40
	sta $1C16+12*40
	sta $1C16+14*40
	sta $1C16+16*40
	lda $1C18+10*40
	sta $1C17+10*40
	sta $1C17+12*40
	sta $1C17+14*40
	sta $1C17+16*40
	lda $1C19+10*40
	sta $1C18+10*40
	sta $1C18+12*40
	sta $1C18+14*40
	sta $1C18+16*40
	lda $1C1A+10*40
	sta $1C19+10*40
	sta $1C19+12*40
	sta $1C19+14*40
	sta $1C19+16*40
	lda $1C1B+10*40
	sta $1C1A+10*40
	sta $1C1A+12*40
	sta $1C1A+14*40
	sta $1C1A+16*40
	lda $1C1C+10*40
	sta $1C1B+10*40
	sta $1C1B+12*40
	sta $1C1B+14*40
	sta $1C1B+16*40
	lda $1C1D+10*40
	sta $1C1C+10*40
	sta $1C1C+12*40
	sta $1C1C+14*40
	sta $1C1C+16*40
	lda $1C1E+10*40
	sta $1C1D+10*40
	sta $1C1D+12*40
	sta $1C1D+14*40
	sta $1C1D+16*40
	lda $1C1F+10*40
	sta $1C1E+10*40
	sta $1C1E+12*40
	sta $1C1E+14*40
	sta $1C1E+16*40
	lda $1C20+10*40
	sta $1C1F+10*40
	sta $1C1F+12*40
	sta $1C1F+14*40
	sta $1C1F+16*40
	lda $1C21+10*40
	sta $1C20+10*40
	sta $1C20+12*40
	sta $1C20+14*40
	sta $1C20+16*40
	lda $1C22+10*40
	sta $1C21+10*40
	sta $1C21+12*40
	sta $1C21+14*40
	sta $1C21+16*40
	lda $1C23+10*40
	sta $1C22+10*40
	sta $1C22+12*40
	sta $1C22+14*40
	sta $1C22+16*40
	lda $1C24+10*40
	sta $1C23+10*40
	sta $1C23+12*40
	sta $1C23+14*40
	sta $1C23+16*40
	lda $1C25+10*40
	sta $1C24+10*40
	sta $1C24+12*40
	sta $1C24+14*40
	sta $1C24+16*40
	lda $1C26+10*40
	sta $1C25+10*40
	sta $1C25+12*40
	sta $1C25+14*40
	sta $1C25+16*40
	lda $1C27+10*40
	sta $1C26+10*40
	sta $1C26+12*40
	sta $1C26+14*40
	sta $1C26+16*40
	inc $1C00+ 9*40+39
	inc $1C00+ 9*40+39
	inc $1C00+10*40+39
	inc $1C00+10*40+39
	inc $1C00+11*40+39
	inc $1C00+11*40+39
	inc $1C00+12*40+39
	inc $1C00+12*40+39
	inc $1C00+13*40+39
	inc $1C00+13*40+39
	inc $1C00+14*40+39
	inc $1C00+14*40+39
	inc $1C00+15*40+39
	inc $1C00+15*40+39
	inc $1C00+16*40+39
	inc $1C00+16*40+39
;	inc $FF19
	rts

copy_dycp_arrays
;	dec $FF19
	lda dycp_font_array+ 1
	sta dycp_font_array+ 0
	lda dycp_font_array+ 2
	sta dycp_font_array+ 1
	lda dycp_font_array+ 3
	sta dycp_font_array+ 2
	lda dycp_font_array+ 4
	sta dycp_font_array+ 3
	lda dycp_font_array+ 5
	sta dycp_font_array+ 4
	lda dycp_font_array+ 6
	sta dycp_font_array+ 5
	lda dycp_font_array+ 7
	sta dycp_font_array+ 6
	lda dycp_font_array+ 8
	sta dycp_font_array+ 7
	lda dycp_font_array+ 9
	sta dycp_font_array+ 8
	lda dycp_font_array+10
	sta dycp_font_array+ 9
	lda dycp_font_array+11
	sta dycp_font_array+10
	lda dycp_font_array+12
	sta dycp_font_array+11
	lda dycp_font_array+13
	sta dycp_font_array+12
	lda dycp_font_array+14
	sta dycp_font_array+13
	lda dycp_font_array+15
	sta dycp_font_array+14
	lda dycp_font_array+16
	sta dycp_font_array+15
	lda dycp_font_array+17
	sta dycp_font_array+16
	lda dycp_font_array+18
	sta dycp_font_array+17
	lda dycp_font_array+19
	sta dycp_font_array+18
	inc dycp_font_array+19
	lda dycp_font_array+19
	and #%00111111
	sta dycp_font_array+19
	lda dycp_sine_array+ 1
	sta dycp_sine_array+ 0
	lda dycp_sine_array+ 2
	sta dycp_sine_array+ 1
	lda dycp_sine_array+ 3
	sta dycp_sine_array+ 2
	lda dycp_sine_array+ 4
	sta dycp_sine_array+ 3
	lda dycp_sine_array+ 5
	sta dycp_sine_array+ 4
	lda dycp_sine_array+ 6
	sta dycp_sine_array+ 5
	lda dycp_sine_array+ 7
	sta dycp_sine_array+ 6
	lda dycp_sine_array+ 8
	sta dycp_sine_array+ 7
	lda dycp_sine_array+ 9
	sta dycp_sine_array+ 8
	lda dycp_sine_array+10
	sta dycp_sine_array+ 9
	lda dycp_sine_array+11
	sta dycp_sine_array+10
	lda dycp_sine_array+12
	sta dycp_sine_array+11
	lda dycp_sine_array+13
	sta dycp_sine_array+12
	lda dycp_sine_array+14
	sta dycp_sine_array+13
	lda dycp_sine_array+15
	sta dycp_sine_array+14
	lda dycp_sine_array+16
	sta dycp_sine_array+15
	lda dycp_sine_array+17
	sta dycp_sine_array+16
	lda dycp_sine_array+18
	sta dycp_sine_array+17
	lda dycp_sine_array+19
	sta dycp_sine_array+18
	inc dycp_sine_array+19
	lda dycp_char_array+ 1
	sta dycp_char_array+ 0
	lda dycp_char_array+ 2
	sta dycp_char_array+ 1
	lda dycp_char_array+ 3
	sta dycp_char_array+ 2
	lda dycp_char_array+ 4
	sta dycp_char_array+ 3
	lda dycp_char_array+ 5
	sta dycp_char_array+ 4
	lda dycp_char_array+ 6
	sta dycp_char_array+ 5
	lda dycp_char_array+ 7
	sta dycp_char_array+ 6
	lda dycp_char_array+ 8
	sta dycp_char_array+ 7
	lda dycp_char_array+ 9
	sta dycp_char_array+ 8
	lda dycp_char_array+10
	sta dycp_char_array+ 9
	lda dycp_char_array+11
	sta dycp_char_array+10
	lda dycp_char_array+12
	sta dycp_char_array+11
	lda dycp_char_array+13
	sta dycp_char_array+12
	lda dycp_char_array+14
	sta dycp_char_array+13
	lda dycp_char_array+15
	sta dycp_char_array+14
	lda dycp_char_array+16
	sta dycp_char_array+15
	lda dycp_char_array+17
	sta dycp_char_array+16
	lda dycp_char_array+18
	sta dycp_char_array+17
	lda dycp_char_array+19
	sta dycp_char_array+18
;	inc $FF19
	rts

FILL_DYCP_CHARS	macro base, char
		ldy #0
		lda low_nibbles,x		; wrapping correction for offset
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x		; wrapping correction for offset
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x		; wrapping correction for offset
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x		; wrapping correction for offset
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		iny
		inx
		lda low_nibbles,x
		tax
		lda (dycp_font_read),y		; read font data
		sta base+char*32+ 0,x		; write font data
		lda (dycp_font_read_2),y	; read font 2nd data
		sta base+char*32+16,x		; write font 2nd data
		rts
		endm

fill_dycp_chars_00_03
	FILL_DYCP_CHARS work_font, $00
fill_dycp_chars_04_07
	FILL_DYCP_CHARS work_font, $01
fill_dycp_chars_08_0B
	FILL_DYCP_CHARS work_font, $02
fill_dycp_chars_0C_0F
	FILL_DYCP_CHARS work_font, $03
fill_dycp_chars_10_13
	FILL_DYCP_CHARS work_font, $04
fill_dycp_chars_14_17
	FILL_DYCP_CHARS work_font, $05
fill_dycp_chars_18_1B
	FILL_DYCP_CHARS work_font, $06
fill_dycp_chars_1C_1F
	FILL_DYCP_CHARS work_font, $07
fill_dycp_chars_20_23
	FILL_DYCP_CHARS work_font, $08
fill_dycp_chars_24_27
	FILL_DYCP_CHARS work_font, $09
fill_dycp_chars_28_2B
	FILL_DYCP_CHARS work_font, $0A
fill_dycp_chars_2C_2F
	FILL_DYCP_CHARS work_font, $0B
fill_dycp_chars_30_33
	FILL_DYCP_CHARS work_font, $0C
fill_dycp_chars_34_37
	FILL_DYCP_CHARS work_font, $0D
fill_dycp_chars_38_3B
	FILL_DYCP_CHARS work_font, $0E
fill_dycp_chars_3C_3F
	FILL_DYCP_CHARS work_font, $0F
fill_dycp_chars_40_43
	FILL_DYCP_CHARS work_font, $10
fill_dycp_chars_44_47
	FILL_DYCP_CHARS work_font, $11
fill_dycp_chars_48_4B
	FILL_DYCP_CHARS work_font, $12
fill_dycp_chars_4C_4F
	FILL_DYCP_CHARS work_font, $13
fill_dycp_chars_50_53
	FILL_DYCP_CHARS work_font, $14
fill_dycp_chars_54_57
	FILL_DYCP_CHARS work_font, $15
fill_dycp_chars_58_5B
	FILL_DYCP_CHARS work_font, $16
fill_dycp_chars_5C_5F
	FILL_DYCP_CHARS work_font, $17
fill_dycp_chars_60_63
	FILL_DYCP_CHARS work_font, $18
fill_dycp_chars_64_67
	FILL_DYCP_CHARS work_font, $19
fill_dycp_chars_68_6B
	FILL_DYCP_CHARS work_font, $1A
fill_dycp_chars_6C_6F
	FILL_DYCP_CHARS work_font, $1B
fill_dycp_chars_70_73
	FILL_DYCP_CHARS work_font, $1C
fill_dycp_chars_74_77
	FILL_DYCP_CHARS work_font, $1D
fill_dycp_chars_78_7B
	FILL_DYCP_CHARS work_font, $1E
fill_dycp_chars_7C_7F
	FILL_DYCP_CHARS work_font, $1F
fill_dycp_chars_80_83
	FILL_DYCP_CHARS work_font, $20
fill_dycp_chars_84_87
	FILL_DYCP_CHARS work_font, $21
fill_dycp_chars_88_8B
	FILL_DYCP_CHARS work_font, $22
fill_dycp_chars_8C_8F
	FILL_DYCP_CHARS work_font, $23
fill_dycp_chars_90_93
	FILL_DYCP_CHARS work_font, $24
fill_dycp_chars_94_97
	FILL_DYCP_CHARS work_font, $25
fill_dycp_chars_98_9B
	FILL_DYCP_CHARS work_font, $26
fill_dycp_chars_9C_9F
	FILL_DYCP_CHARS work_font, $27
fill_dycp_chars_A0_A3
	FILL_DYCP_CHARS work_font, $28
fill_dycp_chars_A4_A7
	FILL_DYCP_CHARS work_font, $29
fill_dycp_chars_A8_AB
	FILL_DYCP_CHARS work_font, $2A
fill_dycp_chars_AC_AF
	FILL_DYCP_CHARS work_font, $2B
fill_dycp_chars_B0_B3
	FILL_DYCP_CHARS work_font, $2C
fill_dycp_chars_B4_B7
	FILL_DYCP_CHARS work_font, $2D
fill_dycp_chars_B8_BB
	FILL_DYCP_CHARS work_font, $2E
fill_dycp_chars_BC_BF
	FILL_DYCP_CHARS work_font, $2F
fill_dycp_chars_C0_C3
	FILL_DYCP_CHARS work_font, $30
fill_dycp_chars_C4_C7
	FILL_DYCP_CHARS work_font, $31
fill_dycp_chars_C8_CB
	FILL_DYCP_CHARS work_font, $32
fill_dycp_chars_CC_CF
	FILL_DYCP_CHARS work_font, $33
fill_dycp_chars_D0_D3
	FILL_DYCP_CHARS work_font, $34
fill_dycp_chars_D4_D7
	FILL_DYCP_CHARS work_font, $35
fill_dycp_chars_D8_DB
	FILL_DYCP_CHARS work_font, $36
fill_dycp_chars_DC_DF
	FILL_DYCP_CHARS work_font, $37
fill_dycp_chars_E0_E3
	FILL_DYCP_CHARS work_font, $38
fill_dycp_chars_E4_E7
	FILL_DYCP_CHARS work_font, $39
fill_dycp_chars_E8_EB
	FILL_DYCP_CHARS work_font, $3A
fill_dycp_chars_EC_EF
	FILL_DYCP_CHARS work_font, $3B
fill_dycp_chars_F0_F3
	FILL_DYCP_CHARS work_font, $3C
fill_dycp_chars_F4_F7
	FILL_DYCP_CHARS work_font, $3D
fill_dycp_chars_F8_FB
	FILL_DYCP_CHARS work_font, $3E
fill_dycp_chars_FC_FF
	FILL_DYCP_CHARS work_font, $3F

	align 256

top_logo_fade_data
	db $00, $00, $00, $00
	db $00, $00, $0E, $00
	db $00, $0E, $00, $0E
	db $00, $0E, $0E, $0E
	db $0E, $0E, $0E, $0E
	db $0E, $0E, $06, $0E
	db $0E, $06, $0E, $06
	db $0E, $06, $06, $06
	db $06, $06, $06, $06
	db $06, $06, $16, $06
	db $06, $16, $06, $16
	db $06, $16, $16, $16
	db $16, $16, $16, $16
	db $16, $16, $26, $16
	db $16, $26, $16, $26
	db $16, $26, $26, $26
	db $26, $26, $26, $26
	db $26, $26, $36, $26
	db $26, $36, $26, $36
	db $26, $36, $36, $36
	db $36, $36, $36, $36
	db $36, $36, $46, $36
	db $36, $46, $36, $46
	db $36, $46, $46, $46
	db $46, $46, $46, $46
	db $46, $46, $56, $46
	db $46, $56, $46, $56
	db $46, $56, $56, $56
	db $56, $56, $56, $56
	db $56, $56, $66, $56
	db $56, $66, $56, $66
	db $56, $66, $66, $66
logo_fade_length			equ		*-top_logo_fade_data-1

dycp_fade_data
	db $00, $00, $00, $00
	db $00, $00, $01, $00
	db $00, $01, $00, $01
	db $00, $01, $01, $01
	db $01, $01, $01, $01
	db $01, $01, $11, $01
	db $01, $11, $01, $11
	db $01, $11, $11, $11
	db $11, $11, $11, $11
	db $11, $11, $21, $11
	db $11, $21, $11, $21
	db $11, $21, $21, $21
	db $21, $21, $21, $21
	db $21, $21, $31, $21
	db $21, $31, $21, $31
	db $21, $31, $31, $31
	db $31, $31, $31, $31
	db $31, $31, $41, $31
	db $31, $41, $31, $41
	db $31, $41, $41, $41
	db $41, $41, $41, $41
	db $41, $41, $51, $41
	db $41, $51, $41, $51
	db $41, $51, $51, $51
	db $51, $51, $51, $51
	db $51, $51, $61, $51
	db $51, $61, $51, $61
	db $51, $61, $61, $61
	db $61, $61, $61, $61
	db $61, $61, $71, $61
	db $61, $71, $61, $71
	db $61, $71, $71, $71
dycp_fade_length			equ		*-dycp_fade_data-1

bottom_logo_fade_data
	db $00, $00, $00, $00
	db $00, $00, $09, $00
	db $00, $09, $00, $09
	db $00, $09, $09, $09
	db $09, $09, $09, $09
	db $09, $09, $02, $09
	db $09, $02, $09, $02
	db $09, $02, $02, $02
	db $02, $02, $02, $02
	db $02, $02, $12, $02
	db $02, $12, $02, $12
	db $02, $12, $12, $12
	db $12, $12, $12, $12
	db $12, $12, $22, $12
	db $12, $22, $12, $22
	db $12, $22, $22, $22
	db $22, $22, $22, $22
	db $22, $22, $32, $22
	db $22, $32, $22, $32
	db $22, $32, $32, $32
	db $32, $32, $32, $32
	db $32, $32, $42, $32
	db $32, $42, $32, $42
	db $32, $42, $42, $42
	db $42, $42, $42, $42
	db $42, $42, $52, $42
	db $42, $52, $42, $52
	db $42, $52, $52, $52
	db $52, $52, $52, $52
	db $52, $52, $62, $52
	db $52, $62, $52, $62
	db $52, $62, $62, $62

top_fade_in
	lda top_swing_flag
	beq exit_tfi
	if LOGO_FADE_DELAY
	dec logo_fade_delay
	bne exit_tfi
	lda #LOGO_FADE_DELAY
	sta logo_fade_delay
	endif
	ldx logo_fade_index
	inx
	stx logo_fade_index
	lda top_logo_fade_data,x
	sta top_colour
exit_tfi
	rts

bottom_fade_in
	lda bottom_swing_flag
	beq exit_bfi
	ldx logo_fade_index
	lda bottom_logo_fade_data,x
	sta bottom_colour
exit_bfi
	rts

dycp_fade_in
	lda dycp_flag
	beq exit_dfi
	ldx dycp_fade_index
	inx
	stx dycp_fade_index
	lda dycp_fade_data,x
	sta dycp_colour_2
	cpx #(dycp_fade_length/2)
	bne dfi_skip
	lda #$21
	sta dycp_colour_1
	sta dycp_colour_3
dfi_skip
	cpx #(3*dycp_fade_length/4)
	bne exit_dfi
	lda #$01
	sta dycp_colour_0
	sta dycp_colour_4
	lda #$41
	sta dycp_colour_1
	sta dycp_colour_3
exit_dfi
	rts

top_fade_out
	lda top_swing_flag
	beq exit_tfo
	if LOGO_FADE_DELAY
	dec logo_fade_delay
	bne exit_tfo
	lda #LOGO_FADE_DELAY
	sta logo_fade_delay
	endif
	ldx logo_fade_index
	dex
	stx logo_fade_index
	lda top_logo_fade_data,x
	sta top_colour
exit_tfo
	rts

bottom_fade_out
	lda bottom_swing_flag
	beq exit_bfo
	ldx logo_fade_index
	lda bottom_logo_fade_data,x
	sta bottom_colour
exit_bfo
	rts

dycp_fade_out
	lda dycp_flag
	beq exit_dfo
	ldx dycp_fade_index
	dex
	stx dycp_fade_index
	lda dycp_fade_data,x
	sta dycp_colour_2
	cpx #(3*dycp_fade_length/4)
	bne dfo_skip_1
	lda #$00
	sta dycp_colour_0
	sta dycp_colour_4
	lda #$21
	sta dycp_colour_1
	sta dycp_colour_3
dfo_skip_1
	cpx #(dycp_fade_length/2)
	bne dfo_skip_2
	lda #$00
	sta dycp_colour_1
	sta dycp_colour_3
dfo_skip_2
	txa
	and #$0F
	bne exit_dfo
	lda vol_bmm
	and #$0F
	beq exit_dfo
	dec vol_bmm
exit_dfo
	rts

main_loop
	lda dycp_font_array+ 0
	ldy dycp_char_array+ 0
	ldx dycp_sine_array+ 0
	inc dycp_sine_array+ 0
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 1
	ldy dycp_char_array+ 1
	ldx dycp_sine_array+ 1
	inc dycp_sine_array+ 1
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 2
	ldy dycp_char_array+ 2
	ldx dycp_sine_array+ 2
	inc dycp_sine_array+ 2
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 3
	ldy dycp_char_array+ 3
	ldx dycp_sine_array+ 3
	inc dycp_sine_array+ 3
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 4
	ldy dycp_char_array+ 4
	ldx dycp_sine_array+ 4
	inc dycp_sine_array+ 4
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 5
	ldy dycp_char_array+ 5
	ldx dycp_sine_array+ 5
	inc dycp_sine_array+ 5
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 6
	ldy dycp_char_array+ 6
	ldx dycp_sine_array+ 6
	inc dycp_sine_array+ 6
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 7
	ldy dycp_char_array+ 7
	ldx dycp_sine_array+ 7
	inc dycp_sine_array+ 7
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 8
	ldy dycp_char_array+ 8
	ldx dycp_sine_array+ 8
	inc dycp_sine_array+ 8
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 9
	ldy dycp_char_array+ 9
	ldx dycp_sine_array+ 9
	inc dycp_sine_array+ 9
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+10
	ldy dycp_char_array+10
	ldx dycp_sine_array+10
	inc dycp_sine_array+10
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+11
	ldy dycp_char_array+11
	ldx dycp_sine_array+11
	inc dycp_sine_array+11
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+12
	ldy dycp_char_array+12
	ldx dycp_sine_array+12
	inc dycp_sine_array+12
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+13
	ldy dycp_char_array+13
	ldx dycp_sine_array+13
	inc dycp_sine_array+13
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+14
	ldy dycp_char_array+14
	ldx dycp_sine_array+14
	inc dycp_sine_array+14
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+15
	ldy dycp_char_array+15
	ldx dycp_sine_array+15
	inc dycp_sine_array+15
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+16
	ldy dycp_char_array+16
	ldx dycp_sine_array+16
	inc dycp_sine_array+16
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+17
	ldy dycp_char_array+17
	ldx dycp_sine_array+17
	inc dycp_sine_array+17
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+18
	ldy dycp_char_array+18
	ldx dycp_sine_array+18
	inc dycp_sine_array+18
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+19
	ldy dycp_char_array+19
	ldx dycp_sine_array+19
	inc dycp_sine_array+19
	jsr dycp_update
	jsr top_logo
	jsr mid_dycp
	jsr bottom_logo
	lda #$7F
	sta $FD30
	sta $FF08
	lda $FF08
	and #$10
	beq fade_out_loop_1
	jmp main_loop
fade_out_loop_1
	lda dycp_font_array+ 0
	ldy dycp_char_array+ 0
	ldx dycp_sine_array+ 0
	inc dycp_sine_array+ 0
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 1
	ldy dycp_char_array+ 1
	ldx dycp_sine_array+ 1
	inc dycp_sine_array+ 1
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 2
	ldy dycp_char_array+ 2
	ldx dycp_sine_array+ 2
	inc dycp_sine_array+ 2
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 3
	ldy dycp_char_array+ 3
	ldx dycp_sine_array+ 3
	inc dycp_sine_array+ 3
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 4
	ldy dycp_char_array+ 4
	ldx dycp_sine_array+ 4
	inc dycp_sine_array+ 4
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 5
	ldy dycp_char_array+ 5
	ldx dycp_sine_array+ 5
	inc dycp_sine_array+ 5
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 6
	ldy dycp_char_array+ 6
	ldx dycp_sine_array+ 6
	inc dycp_sine_array+ 6
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 7
	ldy dycp_char_array+ 7
	ldx dycp_sine_array+ 7
	inc dycp_sine_array+ 7
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 8
	ldy dycp_char_array+ 8
	ldx dycp_sine_array+ 8
	inc dycp_sine_array+ 8
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+ 9
	ldy dycp_char_array+ 9
	ldx dycp_sine_array+ 9
	inc dycp_sine_array+ 9
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+10
	ldy dycp_char_array+10
	ldx dycp_sine_array+10
	inc dycp_sine_array+10
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+11
	ldy dycp_char_array+11
	ldx dycp_sine_array+11
	inc dycp_sine_array+11
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+12
	ldy dycp_char_array+12
	ldx dycp_sine_array+12
	inc dycp_sine_array+12
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+13
	ldy dycp_char_array+13
	ldx dycp_sine_array+13
	inc dycp_sine_array+13
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+14
	ldy dycp_char_array+14
	ldx dycp_sine_array+14
	inc dycp_sine_array+14
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+15
	ldy dycp_char_array+15
	ldx dycp_sine_array+15
	inc dycp_sine_array+15
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+16
	ldy dycp_char_array+16
	ldx dycp_sine_array+16
	inc dycp_sine_array+16
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+17
	ldy dycp_char_array+17
	ldx dycp_sine_array+17
	inc dycp_sine_array+17
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+18
	ldy dycp_char_array+18
	ldx dycp_sine_array+18
	inc dycp_sine_array+18
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_font_array+19
	ldy dycp_char_array+19
	ldx dycp_sine_array+19
	inc dycp_sine_array+19
	jsr dycp_update
	jsr top_logo
	jsr dycp_fade_out
	jsr mid_dycp
	jsr bottom_logo
	lda dycp_fade_index
	beq fade_out_loop_2
	jmp fade_out_loop_1
fade_out_loop_2
	jsr top_fade_out
	jsr top_logo
	jsr bottom_fade_out
	jsr bottom_logo
	cmp logo_fade_index
	bne fade_out_loop_2
	jmp exit_part

	end
